@@ -20,5 +20,5 @@ func main() {
 	// Hardcoding maxFails to 1 since the purpouse here is just to dump the state once
 	reporter := reporter.NewKubernetesReporter(os.Getenv("ARTIFACTS"), 1)
 	reporter.Cleanup()
-	reporter.DumpAllNamespaces(duration)
+	reporter.DumpTestObjects(duration)
 }
