@@ -22,9 +22,6 @@ package main
 import (
 	klog "kubevirt.io/client-go/log"
 
-	_ "kubevirt.io/kubevirt/pkg/monitoring/client/prometheus"    // import for prometheus metrics
-	_ "kubevirt.io/kubevirt/pkg/monitoring/reflector/prometheus" // import for prometheus metrics
-	_ "kubevirt.io/kubevirt/pkg/monitoring/workqueue/prometheus" // import for prometheus metrics
 	"kubevirt.io/kubevirt/pkg/service"
 	virt_api "kubevirt.io/kubevirt/pkg/virt-api"
 )
