@@ -32,12 +32,6 @@ done
     go mod tidy
 )
 
-(
-    cd staging/src/github.com/golang/glog
-    if [ "${_sync_only}" == "false" ]; then go get $@ ./...; fi
-    go mod tidy
-)
-
 (
     cd staging/src/kubevirt.io/client-go/examples/listvms
     if [ "${_sync_only}" == "false" ]; then go get $@ ./...; fi
@@ -45,4 +39,5 @@ done
 )
 
 go mod tidy
-go mod vendor
+go work vendor
+go work sync
