@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
- * Copyright the KubeVirt Authors.
+ * Copyright The KubeVirt Authors.
  */
 
 package client
@@ -23,7 +23,7 @@ import (
 	"net/http"
 	"regexp"
 
-	"github.com/machadovilaca/operator-observability/pkg/operatormetrics"
+	"github.com/rhobs/operator-observability-toolkit/pkg/operatormetrics"
 	"k8s.io/client-go/rest"
 	"k8s.io/client-go/tools/metrics"
 	"kubevirt.io/client-go/kubecli"
@@ -31,6 +31,13 @@ import (
 
 var resourceParsingRegexs []*regexp.Regexp
 
+func init() {
+	metrics.Register(metrics.RegisterOpts{
+		RequestLatency:     &latencyAdapter{requestLatency},
+		RateLimiterLatency: &latencyAdapter{rateLimiterLatency},
+	})
+}
+
 // RegisterRestConfigHooks adds hooks to the KubeVirt client and should be executed before building its config
 func RegisterRestConfigHooks() {
 	setupResourcesToWatch()
@@ -38,11 +45,6 @@ func RegisterRestConfigHooks() {
 }
 
 func SetupMetrics() error {
-	metrics.Register(metrics.RegisterOpts{
-		RequestLatency:     &latencyAdapter{requestLatency},
-		RateLimiterLatency: &latencyAdapter{rateLimiterLatency},
-	})
-
 	return operatormetrics.RegisterMetrics(
 		restMetrics,
 	)
