@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
- * Copyright the KubeVirt Authors.
+ * Copyright The KubeVirt Authors.
  *
  */
 
@@ -75,7 +75,7 @@ var _ = Describe("domain stats collector", func() {
 				vmis:     vmis,
 				vmiStats: vmiStats,
 			}
-			crs := execCollector(concCollector, vmis)
+			crs := execDomainStatsCollector(concCollector, vmis)
 			Expect(crs).To(HaveLen(2))
 			Expect(crs).To(ContainElement(testing.GomegaContainsCollectorResultMatcher(memoryResident, kibibytesToBytes(1))))
 			Expect(crs).To(ContainElement(testing.GomegaContainsCollectorResultMatcher(memoryResident, kibibytesToBytes(2))))
@@ -117,5 +117,5 @@ func fakeCollect(scraper collector.MetricsScraper, wg *sync.WaitGroup, vmi *k6tv
 	defer wg.Done()
 
 	dScraper := scraper.(*DomainstatsScraper)
-	dScraper.report(vmi, vmiStats)
+	report(vmi, vmiStats, dScraper.ch)
 }
