@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
- * Copyright the KubeVirt Authors.
+ * Copyright The KubeVirt Authors.
  *
  */
 
@@ -43,7 +43,7 @@ func NewDomainstatsScraper(channelLength int) *DomainstatsScraper {
 func (d DomainstatsScraper) Scrape(socketFile string, vmi *k6tv1.VirtualMachineInstance) {
 	ts := time.Now()
 
-	exists, vmStats, err := gatherMetrics(socketFile)
+	exists, vmStats, err := d.gatherMetrics(socketFile)
 	if err != nil {
 		log.Log.Reason(err).Errorf("failed to scrape metrics from %s", socketFile)
 		return
@@ -64,7 +64,7 @@ func (d DomainstatsScraper) Scrape(socketFile string, vmi *k6tv1.VirtualMachineI
 		return
 	}
 
-	d.report(vmi, vmStats)
+	report(vmi, vmStats, d.ch)
 }
 
 func (d DomainstatsScraper) GetValues() []VirtualMachineInstanceReport {
@@ -79,23 +79,7 @@ func (d DomainstatsScraper) Complete() {
 	close(d.ch)
 }
 
-func (d DomainstatsScraper) report(vmi *k6tv1.VirtualMachineInstance, vmStats *VirtualMachineInstanceStats) {
-	// statsMaxAge is an estimation - and there is no better way to do that. So it is possible that
-	// GetDomainStats() takes enough time to lag behind, but not enough to trigger the statsMaxAge check.
-	// In this case the next functions will end up writing on a closed channel. This will panic.
-	// It is actually OK in this case to abort the goroutine that panicked -that's what we want anyway,
-	// and the very reason we collect in throwaway goroutines. We need however to avoid dump stacktraces in the logs.
-	// Since this is a known failure condition, let's handle it explicitly.
-	defer func() {
-		if err := recover(); err != nil {
-			log.Log.Warningf("collector goroutine panicked for VM %s: %v", vmi.Name, err)
-		}
-	}()
-
-	d.ch <- newVirtualMachineInstanceReport(vmi, vmStats)
-}
-
-func gatherMetrics(socketFile string) (bool, *VirtualMachineInstanceStats, error) {
+func (d DomainstatsScraper) gatherMetrics(socketFile string) (bool, *VirtualMachineInstanceStats, error) {
 	cli, err := cmdclient.NewClient(socketFile)
 	if err != nil {
 		// Ignore failure to connect to client.
