@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
- * Copyright 2024 Red Hat, Inc.
+ * Copyright The KubeVirt Authors.
  *
  */
 
@@ -30,17 +30,12 @@ func TestAdmitter(t *testing.T) {
 }
 
 type stubClusterConfigChecker struct {
-	slirpEnabled                 bool
 	bridgeBindingOnPodNetEnabled bool
 	macvtapFeatureGateEnabled    bool
 	passtFeatureGateEnabled      bool
 	bindingPluginFGEnabled       bool
 }
 
-func (s stubClusterConfigChecker) IsSlirpInterfaceEnabled() bool {
-	return s.slirpEnabled
-}
-
 func (s stubClusterConfigChecker) IsBridgeInterfaceOnPodNetworkEnabled() bool {
 	return s.bridgeBindingOnPodNetEnabled
 }
