@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
- * Copyright 2022 Red Hat, Inc.
+ * Copyright The KubeVirt Authors.
  *
  */
 package export
@@ -21,6 +21,7 @@ package export
 import (
 	"crypto/tls"
 	"crypto/x509"
+	"encoding/json"
 	"encoding/pem"
 	"fmt"
 	"os"
@@ -30,10 +31,10 @@ import (
 
 	"k8s.io/apimachinery/pkg/util/uuid"
 
-	"github.com/golang/mock/gomock"
 	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
 	"github.com/onsi/gomega/gstruct"
+	"go.uber.org/mock/gomock"
 
 	routev1 "github.com/openshift/api/route/v1"
 	appsv1 "k8s.io/api/apps/v1"
@@ -102,6 +103,7 @@ var (
 			Name:  "TOKEN_FILE",
 			Value: "/token/token",
 		}}
+	tokenSecretName = "my-secret-token"
 )
 
 var _ = Describe("Export controller", func() {
@@ -751,7 +753,7 @@ var _ = Describe("Export controller", func() {
 			Expect(ok).To(BeTrue())
 			service.Status.Conditions = make([]metav1.Condition, 1)
 			service.Status.Conditions[0].Type = "test"
-			Expect(service.GetName()).To(Equal(controller.getExportServiceName(testVMExport)))
+			Expect(service.GetName()).To(Equal("virt-export-test"))
 			Expect(service.GetNamespace()).To(Equal(testNamespace))
 			Expect(service.Labels).To(And(
 				HaveKeyWithValue(virtv1.AppLabel, "virt-exporter"),
@@ -885,7 +887,7 @@ var _ = Describe("Export controller", func() {
 		Expect(pod.Spec.Volumes).To(HaveLen(numberOfVolumes), "There should be 3/4 volumes, one pvc, and two secrets (token and certs) (and vm def manifest if VM)")
 		certSecretName := ""
 		for _, volume := range pod.Spec.Volumes {
-			if volume.Name == certificates {
+			if volume.Name == certificatesVolName {
 				certSecretName = volume.Secret.SecretName
 			}
 		}
@@ -898,7 +900,7 @@ var _ = Describe("Export controller", func() {
 			},
 		}))
 		Expect(pod.Spec.Volumes).To(ContainElement(k8sv1.Volume{
-			Name: certificates,
+			Name: certificatesVolName,
 			VolumeSource: k8sv1.VolumeSource{
 				Secret: &k8sv1.SecretVolumeSource{
 					SecretName: certSecretName,
@@ -906,21 +908,22 @@ var _ = Describe("Export controller", func() {
 			},
 		}))
 		Expect(pod.Spec.Volumes).To(ContainElement(k8sv1.Volume{
-			Name: "token",
+			Name: tokenVolName,
 			VolumeSource: k8sv1.VolumeSource{
 				Secret: &k8sv1.SecretVolumeSource{
-					SecretName: "token",
+					SecretName: tokenSecretName,
 				},
 			},
 		}))
 		Expect(pod.Spec.Containers).To(HaveLen(1))
+		Expect(pod.Spec.Containers[0].Name).To(Equal("exporter"))
 		Expect(pod.Spec.Containers[0].VolumeMounts).To(HaveLen(numberOfVolumes - 1)) // The other is a block Volume
 		Expect(pod.Spec.Containers[0].VolumeMounts).To(ContainElement(k8sv1.VolumeMount{
-			Name:      certificates,
+			Name:      certificatesVolName,
 			MountPath: "/cert",
 		}))
 		Expect(pod.Spec.Containers[0].VolumeMounts).To(ContainElement(k8sv1.VolumeMount{
-			Name:      *testVMExport.Status.TokenSecretRef,
+			Name:      tokenVolName,
 			MountPath: "/token",
 		}))
 		Expect(pod.Spec.Containers[0].VolumeDevices).To(HaveLen(1))
@@ -1013,6 +1016,37 @@ var _ = Describe("Export controller", func() {
 		Entry("PVC name with same length as limit", strings.Repeat("a", validation.DNS1035LabelMaxLength)),
 	)
 
+	DescribeTable("service name should be sanitized", func(exportName, expectedServiceName string) {
+		var service *k8sv1.Service
+		testVMExport := createPVCVMExport()
+		testVMExport.Name = exportName
+		k8sClient.Fake.PrependReactor("create", "services", func(action testing.Action) (handled bool, obj runtime.Object, err error) {
+			create, ok := action.(testing.CreateAction)
+			Expect(ok).To(BeTrue())
+			service, ok = create.GetObject().(*k8sv1.Service)
+			Expect(ok).To(BeTrue())
+			service.Status.Conditions = make([]metav1.Condition, 1)
+			service.Status.Conditions[0].Type = "test"
+			Expect(service.GetName()).To(Equal(expectedServiceName))
+			Expect(service.GetName()).ToNot(ContainSubstring("."))
+			Expect(service.GetName()).ToNot(HavePrefix("-"))
+			Expect(service.GetNamespace()).To(Equal(testNamespace))
+			Expect(service.Labels).To(And(
+				HaveKeyWithValue(virtv1.AppLabel, "virt-exporter"),
+				HaveKeyWithValue(labelKey, labelValue)))
+			Expect(service.Annotations).To(HaveKeyWithValue(annotationKey, annotationValue))
+			return true, service, nil
+		})
+
+		service, err := controller.getOrCreateExportService(testVMExport)
+		Expect(err).ToNot(HaveOccurred())
+		Expect(service).ToNot(BeNil())
+		Expect(service.Status.Conditions[0].Type).To(Equal("test"))
+	},
+		Entry("with dots", fmt.Sprintf("%s.com", vmExportName), "virt-export-test-com"),
+		Entry("special case with - prefix", strings.Repeat("a", validation.DNS1035LabelMaxLength-10), "v-efa2f187-aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa"),
+	)
+
 	It("Should create a secret based on the vm export", func() {
 		cp := &CertParams{Duration: 24 * time.Hour, RenewBefore: 2 * time.Hour}
 		scp, err := serializeCertParams(cp)
@@ -1031,7 +1065,7 @@ var _ = Describe("Export controller", func() {
 			Spec: k8sv1.PodSpec{
 				Volumes: []k8sv1.Volume{
 					{
-						Name: certificates,
+						Name: certificatesVolName,
 						VolumeSource: k8sv1.VolumeSource{
 							Secret: &k8sv1.SecretVolumeSource{
 								SecretName: "test-secret",
@@ -1361,10 +1395,14 @@ var _ = Describe("Export controller", func() {
 		}
 		Expect(instancetypeInformer.GetStore().Add(testInstanceType)).To(Succeed())
 
-		res, err := controller.expandVirtualMachine(vm)
+		res, err := controller.generateVMDefinitionFromVm(vm)
 		Expect(err).ToNot(HaveOccurred())
 		Expect(res).ToNot(BeNil())
-		Expect(res.Spec.Template.Spec.Domain.CPU.Sockets).To(Equal(uint32(2)))
+
+		resVM := &virtv1.VirtualMachine{}
+		Expect(json.Unmarshal(res, resVM)).To(Succeed())
+		Expect(resVM.Spec.Instancetype).To(BeNil())
+		Expect(resVM.Spec.Template.Spec.Domain.CPU.Sockets).To(Equal(uint32(2)))
 	})
 
 	It("Should return error on conflict with instance types of VMs", func() {
@@ -1391,9 +1429,8 @@ var _ = Describe("Export controller", func() {
 		}
 		Expect(instancetypeInformer.GetStore().Add(testInstanceType)).To(Succeed())
 
-		_, err := controller.expandVirtualMachine(vm)
-		Expect(err).To(HaveOccurred())
-		Expect(err.Error()).To(ContainSubstring("cannot expand instancetype to VM, due to 1 conflicts"))
+		_, err := controller.generateVMDefinitionFromVm(vm)
+		Expect(err).To(MatchError(ContainSubstring("VM field(s) spec.template.spec.domain.cpu.cores conflicts with selected instance type")))
 	})
 
 	createVMWithDVTemplateAndPVC := func() *virtv1.VirtualMachine {
@@ -1655,7 +1692,7 @@ func createPVCVMExportWithName(name string) *exportv1.VirtualMachineExport {
 				Kind:     "PersistentVolumeClaim",
 				Name:     testPVCName,
 			},
-			TokenSecretRef: pointer.P("token"),
+			TokenSecretRef: &tokenSecretName,
 		},
 	}
 }
@@ -1682,7 +1719,7 @@ func createSnapshotVMExport() *exportv1.VirtualMachineExport {
 				Kind:     "VirtualMachineSnapshot",
 				Name:     testVmsnapshotName,
 			},
-			TokenSecretRef: pointer.P("token"),
+			TokenSecretRef: &tokenSecretName,
 		},
 	}
 }
@@ -1696,7 +1733,7 @@ func createVMVMExport() *exportv1.VirtualMachineExport {
 				Kind:     "VirtualMachine",
 				Name:     testVmName,
 			},
-			TokenSecretRef: pointer.P("token"),
+			TokenSecretRef: &tokenSecretName,
 		},
 	}
 }
