@@ -448,7 +448,6 @@ func (ctrl *VMSnapshotController) updateVMSnapshotContent(content *snapshotv1.Vi
 
 	created, ready := true, true
 	errorMessage := ""
-	contentCpy.Status.Error = nil
 
 	if len(deletedSnapshots) > 0 {
 		created, ready = false, false
@@ -481,10 +480,14 @@ func (ctrl *VMSnapshotController) updateVMSnapshotContent(content *snapshotv1.Vi
 	}
 
 	if errorMessage != "" && !ready {
-		contentCpy.Status.Error = &snapshotv1.Error{
-			Time:    currentTime(),
-			Message: &errorMessage,
+		if shouldUpdateError(contentCpy, errorMessage) {
+			contentCpy.Status.Error = &snapshotv1.Error{
+				Time:    currentTime(),
+				Message: &errorMessage,
+			}
 		}
+	} else if errorMessage == "" {
+		contentCpy.Status.Error = nil
 	}
 
 	contentCpy.Status.ReadyToUse = &ready
@@ -493,6 +496,10 @@ func (ctrl *VMSnapshotController) updateVMSnapshotContent(content *snapshotv1.Vi
 	return 0, ctrl.updateVmSnapshotContentStatus(content, contentCpy)
 }
 
+func shouldUpdateError(contentCpy *snapshotv1.VirtualMachineSnapshotContent, errorMessage string) bool {
+	return contentCpy.Status.Error == nil || contentCpy.Status.Error.Message == nil || *contentCpy.Status.Error.Message != errorMessage
+}
+
 func (ctrl *VMSnapshotController) updateVmSnapshotContentStatus(oldContent, newContent *snapshotv1.VirtualMachineSnapshotContent) error {
 	if !equality.Semantic.DeepEqual(oldContent.Status, newContent.Status) {
 		if err := ctrl.vmSnapshotContentStatusUpdater.UpdateStatus(newContent); err != nil {
@@ -833,7 +840,9 @@ func updateSnapshotIndications(snapshot *snapshotv1.VirtualMachineSnapshot, sour
 		indications := sets.New(snapshot.Status.Indications...)
 		indications = sets.Insert(indications, snapshotv1.VMSnapshotOnlineSnapshotIndication)
 
-		if source.GuestAgent() {
+		if source.Paused() {
+			indications = sets.Insert(indications, snapshotv1.VMSnapshotPausedIndication)
+		} else if source.GuestAgent() {
 			indications = sets.Insert(indications, snapshotv1.VMSnapshotGuestAgentIndication)
 			snapErr := snapshot.Status.Error
 			if snapErr != nil && snapErr.Message != nil &&
@@ -843,6 +852,7 @@ func updateSnapshotIndications(snapshot *snapshotv1.VirtualMachineSnapshot, sour
 		} else {
 			indications = sets.Insert(indications, snapshotv1.VMSnapshotNoGuestAgentIndication)
 		}
+
 		snapshot.Status.Indications = sets.List(indications)
 	}
 }
