@@ -17,6 +17,9 @@
 package webhooks
 
 import (
+	"fmt"
+	"slices"
+
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	k8sfield "k8s.io/apimachinery/pkg/util/validation/field"
 
@@ -27,9 +30,27 @@ import (
 func ValidateVirtualMachineInstanceS390XSetting(field *k8sfield.Path, spec *v1.VirtualMachineInstanceSpec) []metav1.StatusCause {
 	var statusCauses []metav1.StatusCause
 	validateWatchdogS390x(field, spec, &statusCauses)
+	validateVideoTypeS390x(field, spec, &statusCauses)
 	return statusCauses
 }
 
+func validateVideoTypeS390x(field *k8sfield.Path, spec *v1.VirtualMachineInstanceSpec, statusCauses *[]metav1.StatusCause) {
+	if spec.Domain.Devices.Video == nil {
+		return
+	}
+
+	videoType := spec.Domain.Devices.Video.Type
+
+	validTypes := []string{"virtio"}
+	if !slices.Contains(validTypes, videoType) {
+		*statusCauses = append(*statusCauses, metav1.StatusCause{
+			Type:    metav1.CauseTypeFieldValueNotSupported,
+			Message: fmt.Sprintf("video model '%s' is not supported on s390x architecture", videoType),
+			Field:   field.Child("domain", "devices", "video").Child("type").String(),
+		})
+	}
+}
+
 func validateWatchdogS390x(field *k8sfield.Path, spec *v1.VirtualMachineInstanceSpec, statusCauses *[]metav1.StatusCause) {
 	watchdog := spec.Domain.Devices.Watchdog
 	if watchdog == nil {
@@ -48,3 +69,7 @@ func validateWatchdogS390x(field *k8sfield.Path, spec *v1.VirtualMachineInstance
 func isOnlyDiag288Watchdog(watchdog *v1.Watchdog) bool {
 	return watchdog.WatchdogDevice.Diag288 != nil && watchdog.WatchdogDevice.I6300ESB == nil
 }
+
+func IsS390X(spec *v1.VirtualMachineInstanceSpec) bool {
+	return spec.Architecture == "s390x"
+}
