@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
- * Copyright 2018 Red Hat, Inc.
+ * Copyright The KubeVirt Authors.
  *
  */
 
@@ -518,7 +518,7 @@ var _ = Describe("Validating VMIUpdate Admitter", func() {
 		return res
 	}
 
-	makeDisks := func(indexes ...int) []v1.Disk {
+	makeDisksWithBus := func(bus v1.DiskBus, indexes ...int) []v1.Disk {
 		res := make([]v1.Disk, 0)
 		for _, index := range indexes {
 			bootOrder := uint(index + 1)
@@ -526,7 +526,7 @@ var _ = Describe("Validating VMIUpdate Admitter", func() {
 				Name: fmt.Sprintf("volume-name-%d", index),
 				DiskDevice: v1.DiskDevice{
 					Disk: &v1.DiskTarget{
-						Bus: "scsi",
+						Bus: bus,
 					},
 				},
 				BootOrder: &bootOrder,
@@ -535,6 +535,10 @@ var _ = Describe("Validating VMIUpdate Admitter", func() {
 		return res
 	}
 
+	makeDisks := func(indexes ...int) []v1.Disk {
+		return makeDisksWithBus(v1.DiskBusSCSI, indexes...)
+	}
+
 	makeLUNDisks := func(indexes ...int) []v1.Disk {
 		res := make([]v1.Disk, 0)
 		for _, index := range indexes {
@@ -571,41 +575,40 @@ var _ = Describe("Validating VMIUpdate Admitter", func() {
 
 	makeDisksInvalidBusLastDisk := func(indexes ...int) []v1.Disk {
 		res := makeDisks(indexes...)
-		for i, index := range indexes {
-			if i == len(indexes)-1 {
-				res[index].Disk.Bus = "invalid"
-			}
+		if len(res) > 0 {
+			res[len(res)-1].Disk.Bus = "invalid"
 		}
 		return res
 	}
 
 	makeLUNDisksInvalidBusLastDisk := func(indexes ...int) []v1.Disk {
 		res := makeLUNDisks(indexes...)
-		for i, index := range indexes {
-			if i == len(indexes)-1 {
-				res[index].LUN.Bus = "invalid"
-			}
+		if len(res) > 0 {
+			res[len(res)-1].LUN.Bus = "invalid"
+		}
+		return res
+	}
+
+	makeDisksWithIOThreadsAndBus := func(bus v1.DiskBus, indexes ...int) []v1.Disk {
+		res := makeDisksWithBus(bus, indexes...)
+		if len(res) > 0 {
+			res[len(res)-1].DedicatedIOThread = pointer.P(true)
 		}
 		return res
 	}
 
 	makeDisksWithIOThreads := func(indexes ...int) []v1.Disk {
 		res := makeDisks(indexes...)
-		for i, index := range indexes {
-			if i == len(indexes)-1 {
-				res[index].DedicatedIOThread = pointer.P(true)
-			}
+		if len(res) > 0 {
+			res[len(res)-1].DedicatedIOThread = pointer.P(true)
 		}
 		return res
 	}
 
 	makeDisksInvalidBootOrder := func(indexes ...int) []v1.Disk {
 		res := makeDisks(indexes...)
-		bootOrder := uint(0)
-		for i, index := range indexes {
-			if i == len(indexes)-1 {
-				res[index].BootOrder = &bootOrder
-			}
+		if len(res) > 0 {
+			res[len(res)-1].BootOrder = pointer.P(uint(0))
 		}
 		return res
 	}
@@ -680,12 +683,15 @@ var _ = Describe("Validating VMIUpdate Admitter", func() {
 		Entry("Should return 3 volumes if  1 hotplugged volume", makeVolumes(0, 1, 2, 3), makeStatus(4, 1), makeResult(0, 1, 2)),
 	)
 
-	testHotplugResponse := func(newVolumes, oldVolumes []v1.Volume, newDisks, oldDisks []v1.Disk, filesystems []v1.Filesystem, volumeStatuses []v1.VolumeStatus, expected *admissionv1.AdmissionResponse) {
+	testHotplugResponse := func(newVolumes, oldVolumes []v1.Volume, newDisks, oldDisks []v1.Disk, filesystems []v1.Filesystem, volumeStatuses []v1.VolumeStatus, expected *admissionv1.AdmissionResponse, featureGates ...string) {
 		newVMI := api.NewMinimalVMI("testvmi")
 		newVMI.Spec.Volumes = newVolumes
 		newVMI.Spec.Domain.Devices.Disks = newDisks
 		newVMI.Spec.Domain.Devices.Filesystems = filesystems
 
+		for _, featureGate := range featureGates {
+			enableFeatureGate(featureGate)
+		}
 		result := admitStorageUpdate(newVolumes, oldVolumes, newDisks, oldDisks, volumeStatuses, newVMI, vmiUpdateAdmitter.clusterConfig)
 		Expect(equality.Semantic.DeepEqual(result, expected)).To(BeTrue(), "result: %v and expected: %v do not match", result, expected)
 	}
@@ -706,7 +712,7 @@ var _ = Describe("Validating VMIUpdate Admitter", func() {
 			makeDisks(1),
 			makeFilesystems(),
 			makeStatus(0, 0),
-			makeExpected("number of disks and filesystems (1) does not equal the number of volumes (2)", "")),
+			makeExpected("mismatch between volumes declared (2) and required (1)", "")),
 		Entry("Should reject if we remove a permanent volume",
 			makeVolumes(),
 			makeVolumes(0),
@@ -722,7 +728,7 @@ var _ = Describe("Validating VMIUpdate Admitter", func() {
 			makeDisksNoVolume(0),
 			makeFilesystems(),
 			makeStatus(1, 0),
-			makeExpected("Disk volume-name-1 does not exist", "")),
+			makeExpected("disk volume-name-1 does not exist", "")),
 		Entry("Should reject if we modify existing volume to be invalid",
 			makeVolumes(0, 1),
 			makeVolumes(0, 1),
@@ -755,6 +761,14 @@ var _ = Describe("Validating VMIUpdate Admitter", func() {
 			makeFilesystems(),
 			makeStatus(2, 1),
 			nil),
+		Entry("Should accept if we add volumes and disk properly (virtio bus)",
+			makeVolumes(0, 1),
+			makeVolumes(0),
+			makeDisksWithBus(v1.DiskBusVirtio, 0, 1),
+			makeDisksWithBus(v1.DiskBusVirtio, 0),
+			makeFilesystems(),
+			makeStatus(1, 0),
+			nil),
 		Entry("Should reject if we hotplug a volume with dedicated IOThreads",
 			makeVolumes(0, 1),
 			makeVolumes(0),
@@ -762,7 +776,15 @@ var _ = Describe("Validating VMIUpdate Admitter", func() {
 			makeDisks(0),
 			makeFilesystems(),
 			makeStatus(1, 0),
-			makeExpected("hotplugged Disk volume-name-1 can't use dedicated IOThread: scsi bus is unsupported.", "")),
+			makeExpected("Hotplug configuration for [volume-name-1] requires virtio bus for IOThreads.", "")),
+		Entry("Should accept if we hotplug a virtio volume with dedicated IOThreads",
+			makeVolumes(0, 1),
+			makeVolumes(0),
+			makeDisksWithIOThreadsAndBus(v1.DiskBusVirtio, 0, 1),
+			makeDisksWithBus(v1.DiskBusVirtio, 0),
+			makeFilesystems(),
+			makeStatus(1, 0),
+			nil),
 		Entry("Should accept if we add LUN disk with valid SCSI bus",
 			makeVolumes(0, 1),
 			makeVolumes(0, 1),
@@ -778,7 +800,7 @@ var _ = Describe("Validating VMIUpdate Admitter", func() {
 			makeDisks(0),
 			makeFilesystems(),
 			makeStatus(1, 0),
-			makeExpected("hotplugged Disk volume-name-1 does not use a scsi bus", "")),
+			makeExpected("Hotplug configuration for disk [volume-name-1] requires bus to be 'scsi' or 'virtio'. [invalid] is not permitted.", "")),
 		Entry("Should reject if we add LUN disk with invalid bus",
 			makeVolumes(0, 1),
 			makeVolumes(0),
@@ -786,7 +808,7 @@ var _ = Describe("Validating VMIUpdate Admitter", func() {
 			makeLUNDisks(0),
 			makeFilesystems(),
 			makeStatus(1, 0),
-			makeExpected("hotplugged Disk volume-name-1 does not use a scsi bus", "")),
+			makeExpected("Hotplug configuration for LUN [volume-name-1] requires bus to be 'scsi'. [invalid] is not permitted.", "")),
 		Entry("Should reject if we add disk with neither Disk nor LUN type",
 			makeVolumes(0, 1),
 			makeVolumes(0),
@@ -794,7 +816,32 @@ var _ = Describe("Validating VMIUpdate Admitter", func() {
 			makeCDRomDisks(0),
 			makeFilesystems(),
 			makeStatus(1, 0),
-			makeExpected("Disk volume-name-1 requires diskDevice of type 'disk' or 'lun' to be hotplugged.", "")),
+			makeExpected("Hotplug configuration for [volume-name-1] requires diskDevice of type 'disk' or 'lun' to be used.", "")),
+		Entry("Should allow cd-rom inject",
+			makeVolumes(0, 1),
+			makeVolumes(0),
+			makeCDRomDisks(0, 1),
+			makeCDRomDisks(0, 1),
+			makeFilesystems(),
+			makeStatus(1, 0),
+			nil),
+		Entry("Should allow cd-rom eject",
+			makeVolumes(0),
+			makeVolumes(0, 1),
+			makeCDRomDisks(0, 1),
+			makeCDRomDisks(0, 1),
+			makeFilesystems(),
+			makeStatus(1, 0),
+			nil,
+			featuregate.DeclarativeHotplugVolumesGate),
+		Entry("Should reject cd-rom eject",
+			makeVolumes(0),
+			makeVolumes(0, 1),
+			makeCDRomDisks(0, 1),
+			makeCDRomDisks(0, 1),
+			makeFilesystems(),
+			makeStatus(1, 0),
+			makeExpected("mismatch between volumes declared (1) and required (2)", "")),
 		Entry("Should reject if we add disk with invalid boot order",
 			makeVolumes(0, 1),
 			makeVolumes(0),
@@ -818,7 +865,7 @@ var _ = Describe("Validating VMIUpdate Admitter", func() {
 			makeDisks(1),
 			makeFilesystems(),
 			makeStatus(0, 0),
-			makeExpected("number of disks and filesystems (1) does not equal the number of volumes (2)", "")),
+			makeExpected("mismatch between volumes declared (2) and required (1)", "")),
 	)
 
 	Context("with filesystem devices", func() {
@@ -843,7 +890,7 @@ var _ = Describe("Validating VMIUpdate Admitter", func() {
 				makeDisks(0),
 				makeFilesystems(1),
 				makeStatus(2, 0),
-				makeExpected("number of disks and filesystems (2) does not equal the number of volumes (3)", "")),
+				makeExpected("mismatch between volumes declared (3) and required (2)", "")),
 		)
 	})
 
