@@ -15,6 +15,7 @@ import (
 	"kubevirt.io/client-go/log"
 
 	"kubevirt.io/kubevirt/pkg/config"
+	containerdisk "kubevirt.io/kubevirt/pkg/container-disk"
 	"kubevirt.io/kubevirt/pkg/hooks"
 	hostdisk "kubevirt.io/kubevirt/pkg/host-disk"
 	"kubevirt.io/kubevirt/pkg/network/downwardapi"
@@ -26,6 +27,7 @@ import (
 type VolumeRendererOption func(renderer *VolumeRenderer) error
 
 type VolumeRenderer struct {
+	useImageVolumes       bool
 	containerDiskDir      string
 	ephemeralDiskDir      string
 	virtShareDir          string
@@ -37,8 +39,9 @@ type VolumeRenderer struct {
 	volumeDevices         []k8sv1.VolumeDevice
 }
 
-func NewVolumeRenderer(namespace string, ephemeralDisk string, containerDiskDir string, virtShareDir string, volumeOptions ...VolumeRendererOption) (*VolumeRenderer, error) {
+func NewVolumeRenderer(imageVolumeFeatureGateEnabled bool, namespace string, ephemeralDisk string, containerDiskDir string, virtShareDir string, volumeOptions ...VolumeRendererOption) (*VolumeRenderer, error) {
 	volumeRenderer := &VolumeRenderer{
+		useImageVolumes:  imageVolumeFeatureGateEnabled,
 		containerDiskDir: containerDiskDir,
 		ephemeralDiskDir: ephemeralDisk,
 		namespace:        namespace,
@@ -57,10 +60,12 @@ func (vr *VolumeRenderer) Mounts() []k8sv1.VolumeMount {
 		mountPath("private", util.VirtPrivateDir),
 		mountPath("public", util.VirtShareDir),
 		mountPath("ephemeral-disks", vr.ephemeralDiskDir),
-		mountPathWithPropagation(containerDisks, vr.containerDiskDir, k8sv1.MountPropagationHostToContainer),
 		mountPath("libvirt-runtime", "/var/run/libvirt"),
 		mountPath("sockets", filepath.Join(vr.virtShareDir, "sockets")),
 	}
+	if !vr.useImageVolumes {
+		volumeMounts = append(volumeMounts, mountPathWithPropagation(containerDisks, vr.containerDiskDir, k8sv1.MountPropagationHostToContainer))
+	}
 	return append(volumeMounts, vr.podVolumeMounts...)
 }
 
@@ -72,7 +77,9 @@ func (vr *VolumeRenderer) Volumes() []k8sv1.Volume {
 		emptyDirVolume(virtBinDir),
 		emptyDirVolume("libvirt-runtime"),
 		emptyDirVolume("ephemeral-disks"),
-		emptyDirVolume(containerDisks),
+	}
+	if !vr.useImageVolumes {
+		volumes = append(volumes, emptyDirVolume(containerDisks))
 	}
 	return append(volumes, vr.podVolumes...)
 }
@@ -219,6 +226,24 @@ func withVMIConfigVolumes(vmiDisks []v1.Disk, vmiVolumes []v1.Volume) VolumeRend
 	}
 }
 
+func withImageVolumes(vmi *v1.VirtualMachineInstance) VolumeRendererOption {
+	return func(renderer *VolumeRenderer) error {
+		for i, volume := range vmi.Spec.Volumes {
+			if volume.ContainerDisk != nil {
+				renderer.addContainerDiskVolume(volume)
+				renderer.addContainerDiskVolumeMount(volume, i)
+			}
+		}
+
+		if util.HasKernelBootContainerImage(vmi) {
+			kbc := vmi.Spec.Domain.Firmware.KernelBoot.Container
+			renderer.addKernelBootVolume(kbc)
+			renderer.addKernelBootVolumeMount()
+		}
+		return nil
+	}
+}
+
 func (vr *VolumeRenderer) handleCloudInitConfigDrive(volume v1.Volume) {
 	if volume.CloudInitConfigDrive != nil {
 		if volume.CloudInitConfigDrive.UserDataSecretRef != nil {
@@ -697,6 +722,46 @@ func (vr *VolumeRenderer) addDownwardAPIVolumeMount(volume v1.Volume) {
 	})
 }
 
+func (vr *VolumeRenderer) addContainerDiskVolume(volume v1.Volume) {
+	vr.podVolumes = append(vr.podVolumes, k8sv1.Volume{
+		Name: volume.Name,
+		VolumeSource: k8sv1.VolumeSource{
+			Image: &k8sv1.ImageVolumeSource{
+				Reference:  volume.ContainerDisk.Image,
+				PullPolicy: volume.ContainerDisk.ImagePullPolicy,
+			},
+		},
+	})
+}
+
+func (vr *VolumeRenderer) addContainerDiskVolumeMount(volume v1.Volume, volumeIndex int) {
+	vr.podVolumeMounts = append(vr.podVolumeMounts, k8sv1.VolumeMount{
+		Name:      volume.Name,
+		MountPath: filepath.Join(filepath.Join(util.VirtImageVolumeDir), fmt.Sprintf("disk_%d", volumeIndex)),
+		ReadOnly:  true,
+	})
+}
+
+func (vr *VolumeRenderer) addKernelBootVolume(kbc *v1.KernelBootContainer) {
+	vr.podVolumes = append(vr.podVolumes, k8sv1.Volume{
+		Name: containerdisk.KernelBootName,
+		VolumeSource: k8sv1.VolumeSource{
+			Image: &k8sv1.ImageVolumeSource{
+				Reference:  kbc.Image,
+				PullPolicy: kbc.ImagePullPolicy,
+			},
+		},
+	})
+}
+
+func (vr *VolumeRenderer) addKernelBootVolumeMount() {
+	vr.podVolumeMounts = append(vr.podVolumeMounts, k8sv1.VolumeMount{
+		Name:      containerdisk.KernelBootName,
+		MountPath: util.VirtKernelBootVolumeDir,
+		ReadOnly:  true,
+	})
+}
+
 func (vr *VolumeRenderer) handleCloudInitNoCloud(volume v1.Volume) {
 	if volume.CloudInitNoCloud.UserDataSecretRef != nil {
 		// attach a secret referenced by the user
