@@ -13,7 +13,7 @@ import (
 	virtconfig "kubevirt.io/kubevirt/pkg/virt-config"
 )
 
-func generateSerialConsoleLogContainer(vmi *v1.VirtualMachineInstance, image string, config *virtconfig.ClusterConfig, virtLauncherLogVerbosity uint, socketTimeout string) *k8sv1.Container {
+func generateSerialConsoleLogContainer(vmi *v1.VirtualMachineInstance, image string, config *virtconfig.ClusterConfig, virtLauncherLogVerbosity uint) *k8sv1.Container {
 	const serialPort = 0
 	if isSerialConsoleLogEnabled(vmi, config) {
 		logFile := fmt.Sprintf("%s/%s/virt-serial%d-log", util.VirtPrivateDir, vmi.ObjectMeta.UID, serialPort)
@@ -25,9 +25,9 @@ func generateSerialConsoleLogContainer(vmi *v1.VirtualMachineInstance, image str
 			Image:           image,
 			ImagePullPolicy: k8sv1.PullIfNotPresent,
 			Command:         []string{"/usr/bin/virt-tail"},
-			Args:            []string{"--logfile", logFile, "--socket-timeout", socketTimeout},
+			Args:            []string{"--logfile", logFile},
 			VolumeMounts: []k8sv1.VolumeMount{
-				k8sv1.VolumeMount{
+				{
 					Name:      "private",
 					MountPath: util.VirtPrivateDir,
 					ReadOnly:  true,
@@ -42,6 +42,7 @@ func generateSerialConsoleLogContainer(vmi *v1.VirtualMachineInstance, image str
 					Drop: []k8sv1.Capability{"ALL"},
 				},
 			},
+			RestartPolicy: pointer.P(k8sv1.ContainerRestartPolicyAlways),
 		}
 
 		guestConsoleLog.Env = append(guestConsoleLog.Env, k8sv1.EnvVar{Name: ENV_VAR_VIRT_LAUNCHER_LOG_VERBOSITY, Value: fmt.Sprint(virtLauncherLogVerbosity)})
