@@ -1371,18 +1371,30 @@ func alignPodMultiCategorySecurity(pod *k8sv1.Pod, selinuxType string, dockerSEL
 
 func matchSELinuxLevelOfVMI(pod *k8sv1.Pod, vmi *v1.VirtualMachineInstance) error {
 	if vmi.Status.SelinuxContext == "" {
+		if vmi.Status.MigrationState != nil && vmi.Status.MigrationState.SourceState != nil && vmi.Status.MigrationState.SourceState.SelinuxContext != "" {
+			selinuxContext := vmi.Status.MigrationState.SourceState.SelinuxContext
+			if selinuxContext != "none" {
+				return setSELinuxContext(selinuxContext, pod)
+			}
+			return nil
+		}
 		return fmt.Errorf("VMI is missing SELinux context")
 	} else if vmi.Status.SelinuxContext != "none" {
-		ctx := strings.Split(vmi.Status.SelinuxContext, ":")
-		if len(ctx) < 4 {
-			return fmt.Errorf("VMI has invalid SELinux context: %s", vmi.Status.SelinuxContext)
-		}
-		pod.Spec.Containers[0].SecurityContext.SELinuxOptions.Level = strings.Join(ctx[3:], ":")
+		return setSELinuxContext(vmi.Status.SelinuxContext, pod)
 	}
 
 	return nil
 }
 
+func setSELinuxContext(selinuxContext string, pod *k8sv1.Pod) error {
+	ctx := strings.Split(selinuxContext, ":")
+	if len(ctx) < 4 {
+		return fmt.Errorf("VMI has invalid SELinux context: %s", selinuxContext)
+	}
+	pod.Spec.Containers[0].SecurityContext.SELinuxOptions.Level = strings.Join(ctx[3:], ":")
+	return nil
+}
+
 func generateContainerSecurityContext(selinuxType string, container *k8sv1.Container) {
 	if container.SecurityContext == nil {
 		container.SecurityContext = &k8sv1.SecurityContext{}
@@ -1514,6 +1526,10 @@ func (t *templateService) VMIResourcePredicates(vmi *v1.VirtualMachineInstance,
 	return VMIResourcePredicates{
 		vmi: vmi,
 		resourceRules: []VMIResourceRule{
+			// Run overcommit first to avoid overcommitting overhead memory
+			NewVMIResourceRule(func(vmi *v1.VirtualMachineInstance) bool {
+				return t.clusterConfig.GetMemoryOvercommit() != 100
+			}, WithMemoryOvercommit(t.clusterConfig.GetMemoryOvercommit())),
 			NewVMIResourceRule(doesVMIRequireDedicatedCPU, WithCPUPinning(vmi, vmi.Annotations, additionalCPUs)),
 			NewVMIResourceRule(not(doesVMIRequireDedicatedCPU), WithoutDedicatedCPU(vmi, t.clusterConfig.GetCPUAllocationRatio(), withCPULimits)),
 			NewVMIResourceRule(hasHugePages, WithHugePages(vmi.Spec.Domain.Memory, memoryOverhead)),
