@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
- * Copyright 2017, 2018 Red Hat, Inc.
+ * Copyright The KubeVirt Authors.
  *
  */
 
@@ -62,6 +62,8 @@ import (
 	"k8s.io/client-go/tools/record"
 	"k8s.io/client-go/util/flowcontrol"
 
+	"kubevirt.io/kubevirt/pkg/virt-controller/watch/dra"
+
 	"kubevirt.io/kubevirt/pkg/util/ratelimiter"
 
 	"kubevirt.io/kubevirt/pkg/virt-controller/watch/topology"
@@ -80,7 +82,6 @@ import (
 	"kubevirt.io/kubevirt/pkg/controller"
 	clusterutil "kubevirt.io/kubevirt/pkg/util/cluster"
 
-	"kubevirt.io/kubevirt/pkg/instancetype"
 	instancetypecontroller "kubevirt.io/kubevirt/pkg/instancetype/controller/vm"
 	clientmetrics "kubevirt.io/kubevirt/pkg/monitoring/metrics/common/client"
 	metrics "kubevirt.io/kubevirt/pkg/monitoring/metrics/virt-controller"
@@ -97,6 +98,7 @@ import (
 
 	netadmitter "kubevirt.io/kubevirt/pkg/network/admitter"
 	netcontrollers "kubevirt.io/kubevirt/pkg/network/controllers"
+	netmigration "kubevirt.io/kubevirt/pkg/network/migration"
 	"kubevirt.io/kubevirt/pkg/network/netbinding"
 	netannotations "kubevirt.io/kubevirt/pkg/network/pod/annotations"
 	storageannotations "kubevirt.io/kubevirt/pkg/storage/pod/annotations"
@@ -141,19 +143,22 @@ var (
 type VirtControllerApp struct {
 	service.ServiceListen
 
-	clientSet       kubecli.KubevirtClient
-	templateService services.TemplateService
-	restClient      *clientrest.RESTClient
-	informerFactory controller.KubeInformerFactory
-	kvPodInformer   cache.SharedIndexInformer
+	clientSet             kubecli.KubevirtClient
+	templateService       services.TemplateService
+	restClient            *clientrest.RESTClient
+	informerFactory       controller.KubeInformerFactory
+	kvPodInformer         cache.SharedIndexInformer
+	resourceClaimInformer cache.SharedIndexInformer
+	resourceSliceInformer cache.SharedIndexInformer
 
 	nodeInformer   cache.SharedIndexInformer
 	nodeController *node.Controller
 
-	vmiCache      cache.Store
-	vmiController *vmi.Controller
-	vmiInformer   cache.SharedIndexInformer
-	vmiRecorder   record.EventRecorder
+	vmiCache            cache.Store
+	vmiController       *vmi.Controller
+	draStatusController *dra.DRAStatusController
+	vmiInformer         cache.SharedIndexInformer
+	vmiRecorder         record.EventRecorder
 
 	namespaceInformer cache.SharedIndexInformer
 	namespaceStore    cache.Store
@@ -238,12 +243,15 @@ type VirtControllerApp struct {
 
 	// indicates if controllers were started with or without CDI/DataVolume support
 	hasCDI bool
+	// indicates if controllers were started with or without DRA support
+	isDRAEnabled bool
 	// the channel used to trigger re-initialization.
 	reInitChan chan string
 
 	// number of threads for each controller
 	nodeControllerThreads             int
 	vmiControllerThreads              int
+	draStatusControllerThreads        int
 	rsControllerThreads               int
 	poolControllerThreads             int
 	vmControllerThreads               int
@@ -341,6 +349,7 @@ func Execute() {
 
 	app.reInitChan = make(chan string, 10)
 	app.hasCDI = app.clusterConfig.HasDataVolumeAPI()
+	app.isDRAEnabled = app.clusterConfig.GPUsWithDRAGateEnabled() || app.clusterConfig.HostDevicesWithDRAEnabled()
 	app.clusterConfig.SetConfigModifiedCallback(app.configModificationCallback)
 	app.clusterConfig.SetConfigModifiedCallback(app.shouldChangeLogVerbosity)
 	app.clusterConfig.SetConfigModifiedCallback(app.shouldChangeRateLimiter)
@@ -359,6 +368,15 @@ func Execute() {
 
 	app.vmiInformer = app.informerFactory.VMI()
 	app.kvPodInformer = app.informerFactory.KubeVirtPod()
+	if app.isDRAEnabled {
+		app.resourceClaimInformer = app.informerFactory.ResourceClaim()
+		app.resourceSliceInformer = app.informerFactory.ResourceSlice()
+		log.Log.Infof("One of DRA FG detected, DRA integration enabled")
+	} else {
+		app.resourceClaimInformer = app.informerFactory.DummyResourceClaim()
+		app.resourceSliceInformer = app.informerFactory.DummyResourceSlice()
+		log.Log.Infof("No DRA FG detected, DRA integration disabled")
+	}
 	app.nodeInformer = app.informerFactory.KubeVirtNode()
 	app.namespaceStore = app.informerFactory.Namespace().GetStore()
 	app.namespaceInformer = app.informerFactory.Namespace()
@@ -433,21 +451,27 @@ func Execute() {
 
 	app.onOpenshift = onOpenShift
 
+	metricsInformers := &metrics.Informers{
+		VM:                    app.vmInformer,
+		VMI:                   app.vmiInformer,
+		PersistentVolumeClaim: app.persistentVolumeClaimInformer,
+		VMIMigration:          app.migrationInformer,
+		KVPod:                 app.kvPodInformer,
+	}
+
+	metricsStores := &metrics.Stores{
+		Instancetype:        app.instancetypeInformer.GetStore(),
+		ClusterInstancetype: app.clusterInstancetypeInformer.GetStore(),
+		Preference:          app.preferenceInformer.GetStore(),
+		ClusterPreference:   app.clusterPreferenceInformer.GetStore(),
+		ControllerRevision:  app.controllerRevisionInformer.GetStore(),
+	}
+
 	if err := metrics.SetupMetrics(
-		app.vmInformer,
-		app.vmiInformer,
-		app.persistentVolumeClaimInformer,
-		app.migrationInformer,
-		app.kvPodInformer,
+		metricsInformers,
+		metricsStores,
 		app.clusterConfig,
-		&instancetype.InstancetypeMethods{
-			InstancetypeStore:        app.instancetypeInformer.GetStore(),
-			ClusterInstancetypeStore: app.clusterInstancetypeInformer.GetStore(),
-			PreferenceStore:          app.preferenceInformer.GetStore(),
-			ClusterPreferenceStore:   app.clusterInstancetypeInformer.GetStore(),
-			ControllerRevisionStore:  app.controllerRevisionInformer.GetStore(),
-			Clientset:                app.clientSet,
-		},
+		app.clientSet,
 	); err != nil {
 		golog.Fatal(err)
 	}
@@ -480,6 +504,17 @@ func (vca *VirtControllerApp) configModificationCallback() {
 			log.Log.Infof("Reinitialize virt-controller, cdi api has been removed")
 		}
 		vca.reInitChan <- "reinit"
+		return
+	}
+	newIsDRAEnabled := vca.clusterConfig.GPUsWithDRAGateEnabled() || vca.clusterConfig.HostDevicesWithDRAEnabled()
+	if newIsDRAEnabled != vca.isDRAEnabled {
+		if newIsDRAEnabled {
+			log.Log.Infof("Reinitialize virt-controller, DRA integration has been introduced")
+		} else {
+			log.Log.Infof("Reinitialize virt-controller, DRA integration has been removed")
+		}
+		vca.reInitChan <- "reinit"
+		return
 	}
 }
 
@@ -569,6 +604,9 @@ func (vca *VirtControllerApp) onStartedLeading() func(ctx context.Context) {
 		go vca.disruptionBudgetController.Run(vca.disruptionBudgetControllerThreads, stop)
 		go vca.nodeController.Run(vca.nodeControllerThreads, stop)
 		go vca.vmiController.Run(vca.vmiControllerThreads, stop)
+		if vca.isDRAEnabled {
+			go vca.draStatusController.Run(vca.draStatusControllerThreads, stop)
+		}
 		go vca.rsController.Run(vca.rsControllerThreads, stop)
 		go vca.poolController.Run(vca.poolControllerThreads, stop)
 		go vca.vmController.Run(vca.vmControllerThreads, stop)
@@ -666,11 +704,25 @@ func (vca *VirtControllerApp) initCommon() {
 		func(field *k8sfield.Path, vmiSpec *v1.VirtualMachineInstanceSpec, clusterCfg *virtconfig.ClusterConfig) []metav1.StatusCause {
 			return netadmitter.ValidateCreation(field, vmiSpec, clusterCfg)
 		},
+		netmigration.NewEvaluator(),
 	)
 	if err != nil {
 		panic(err)
 	}
 
+	if vca.isDRAEnabled {
+		draStatusRecorder := vca.newRecorder(k8sv1.NamespaceAll, "dra-status-controller")
+		vca.draStatusController, err = dra.NewDRAStatusController(
+			vca.clusterConfig,
+			vca.vmiInformer,
+			vca.kvPodInformer,
+			vca.resourceClaimInformer,
+			vca.resourceSliceInformer,
+			draStatusRecorder,
+			vca.clientSet,
+		)
+	}
+
 	recorder := vca.newRecorder(k8sv1.NamespaceAll, "node-controller")
 	vca.nodeController, err = node.NewController(vca.clientSet, vca.nodeInformer, vca.vmiInformer, recorder)
 	if err != nil {
@@ -690,9 +742,9 @@ func (vca *VirtControllerApp) initCommon() {
 		vca.persistentVolumeClaimInformer,
 		vca.storageClassInformer,
 		vca.storageProfileInformer,
-		vca.pdbInformer,
 		vca.migrationPolicyInformer,
 		vca.resourceQuotaInformer,
+		vca.kubeVirtInformer,
 		vca.vmiRecorder,
 		clientSet,
 		vca.clusterConfig,
@@ -740,14 +792,13 @@ func (vca *VirtControllerApp) initVirtualMachines() {
 		vca.namespaceStore,
 		vca.persistentVolumeClaimInformer,
 		vca.controllerRevisionInformer,
-		vca.kvPodInformer,
 		recorder,
 		vca.clientSet,
 		vca.clusterConfig,
 		netcontrollers.NewVMController(
 			vca.clientSet.GeneratedKubeVirtClient(),
-			controller.NewPodCacheStore(vca.kvPodInformer.GetIndexer()),
 		),
+		vm.NewFirmwareController(vca.clientSet.GeneratedKubeVirtClient()),
 		instancetypecontroller.New(
 			vca.instancetypeInformer.GetStore(),
 			vca.clusterInstancetypeInformer.GetStore(),
@@ -774,7 +825,6 @@ func (vca *VirtControllerApp) initDisruptionBudgetController() {
 		vca.migrationInformer,
 		recorder,
 		vca.clientSet,
-		vca.clusterConfig,
 	)
 	if err != nil {
 		panic(err)
@@ -966,6 +1016,9 @@ func (vca *VirtControllerApp) AddFlags() {
 	flag.IntVar(&vca.vmiControllerThreads, "vmi-controller-threads", defaultVMIControllerThreads,
 		"Number of goroutines to run for vmi controller")
 
+	flag.IntVar(&vca.draStatusControllerThreads, "dra-status-controller-threads", defaultControllerThreads,
+		"Number of goroutines to run for dra status controller")
+
 	flag.IntVar(&vca.rsControllerThreads, "rs-controller-threads", defaultControllerThreads,
 		"Number of goroutines to run for replicaset controller")
 
