@@ -12,7 +12,7 @@
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
- * Copyright 2022 Red Hat, Inc.
+ * Copyright The KubeVirt Authors.
  *
  */
 
@@ -25,9 +25,9 @@ import (
 	"strings"
 
 	jsonpatch "github.com/evanphx/json-patch"
-	"github.com/golang/mock/gomock"
 	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
+	"go.uber.org/mock/gomock"
 	k8sv1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
@@ -559,6 +559,7 @@ var _ = Describe("Clone", func() {
 				It("should update the clone phase", func() {
 					snapshot := createVirtualMachineSnapshot(sourceVM)
 					snapshot.Status.ReadyToUse = pointer.P(true)
+					snapshotContent := createVirtualMachineSnapshotContent(sourceVM)
 
 					restore := createVirtualMachineRestore(sourceVM, snapshot.Name)
 
@@ -569,6 +570,7 @@ var _ = Describe("Clone", func() {
 					addVM(sourceVM)
 					addClone(vmClone)
 					addSnapshot(snapshot)
+					addSnapshotContent(snapshotContent)
 					addRestore(restore)
 
 					sanityExecute()
@@ -618,6 +620,17 @@ var _ = Describe("Clone", func() {
 		})
 
 		Context("with source snapshot", func() {
+			It("should report event if source Snapshot doesn't exist, phase shouldn't change", func() {
+				snapshot := createVirtualMachineSnapshot(sourceVM)
+				setSnapshotSource(vmClone, snapshot.Name)
+
+				addClone(vmClone)
+
+				sanityExecute()
+				expectEvent(SourceDoesNotExist)
+				expectCloneBeInPhase(clone.PhaseUnset)
+			})
+
 			It("when snapshot is not ready yet - should not do anything", func() {
 				snapshot := createVirtualMachineSnapshot(sourceVM)
 				snapshot.Status.ReadyToUse = pointer.P(false)
@@ -636,6 +649,64 @@ var _ = Describe("Clone", func() {
 				expectRestoreDoesNotExist()
 			})
 
+			It("should fail clone if snaphshot ready - but snapshotcontent is invalid", func() {
+				snapshot := createVirtualMachineSnapshot(sourceVM)
+				snapshot.Status.ReadyToUse = pointer.P(true)
+				snapshotContent := createVirtualMachineSnapshotContent(sourceVM)
+				snapshotContent.Spec.VirtualMachineSnapshotName = nil
+				setSnapshotSource(vmClone, snapshot.Name)
+
+				addClone(vmClone)
+				addSnapshot(snapshot)
+				addSnapshotContent(snapshotContent)
+
+				sanityExecute()
+				expectEvent(SnapshotContentInvalid)
+				expectCloneBeInPhase(clone.Failed)
+			})
+
+			It("clone should fail if source VMSnapshot has backendstorage", func() {
+				snapshot := createVirtualMachineSnapshot(sourceVM)
+				snapshot.Status.ReadyToUse = pointer.P(true)
+				snapshotContent := createVirtualMachineSnapshotContent(sourceVM)
+				snapshotContent.Spec.Source.VirtualMachine.Spec.Template.Spec.Domain.Devices.TPM = &virtv1.TPMDevice{
+					Persistent: pointer.P(true),
+				}
+
+				setSnapshotSource(vmClone, snapshot.Name)
+
+				addClone(vmClone)
+				addSnapshot(snapshot)
+				addSnapshotContent(snapshotContent)
+
+				sanityExecute()
+				expectEvent(SnapshotContentInvalid)
+				expectCloneBeInPhase(clone.Failed)
+			})
+
+			It("should fail clone if snaphshot ready - but not all volumes were snapshoted", func() {
+				snapshot := createVirtualMachineSnapshot(sourceVM)
+				snapshot.Status.ReadyToUse = pointer.P(true)
+				snapshotContent := createVirtualMachineSnapshotContent(sourceVM)
+				snapshotContent.Spec.Source.VirtualMachine.Spec.Template.Spec.Volumes = append(snapshotContent.Spec.Source.VirtualMachine.Spec.Template.Spec.Volumes, virtv1.Volume{
+					Name: "vol1",
+					VolumeSource: virtv1.VolumeSource{
+						DataVolume: &virtv1.DataVolumeSource{
+							Name: "dv1",
+						},
+					},
+				})
+				setSnapshotSource(vmClone, snapshot.Name)
+
+				addClone(vmClone)
+				addSnapshot(snapshot)
+				addSnapshotContent(snapshotContent)
+
+				sanityExecute()
+				expectEvent(SnapshotContentInvalid)
+				expectCloneBeInPhase(clone.Failed)
+			})
+
 			It("when snapshot is ready - should update status and create restore", func() {
 				snapshot := createVirtualMachineSnapshot(sourceVM)
 				snapshot.Status.ReadyToUse = pointer.P(true)
@@ -656,6 +727,7 @@ var _ = Describe("Clone", func() {
 			It("when restore already exists and vmclone is not update yet - should update the clone phase", func() {
 				snapshot := createVirtualMachineSnapshot(sourceVM)
 				snapshot.Status.ReadyToUse = pointer.P(true)
+				snapshotContent := createVirtualMachineSnapshotContent(sourceVM)
 
 				setSnapshotSource(vmClone, snapshot.Name)
 
@@ -666,6 +738,7 @@ var _ = Describe("Clone", func() {
 
 				addClone(vmClone)
 				addSnapshot(snapshot)
+				addSnapshotContent(snapshotContent)
 				addRestore(restore)
 
 				sanityExecute()
@@ -950,6 +1023,85 @@ var _ = Describe("Clone", func() {
 			})
 		})
 
+		It("Custom patches should be applied to the VM", func() {
+			patchSet := patch.New(
+				patch.WithAdd("/spec/template/metadata/labels/example", "extra-label"),
+				patch.WithReplace("/spec/template/spec/architecture", "new-architecture"),
+				patch.WithRemove("/spec/template/metadata/labels/label-to-remove"),
+			)
+
+			var err error
+			vmClone.Spec.Patches, err = patchSet.ToSlice()
+			Expect(err).NotTo(HaveOccurred())
+
+			// Extra label we want to remove from the spec labels
+			sourceVM.Spec.Template.ObjectMeta.Labels = make(map[string]string)
+			sourceVM.Spec.Template.ObjectMeta.Labels["label-to-remove"] = "some-value"
+
+			addVM(sourceVM)
+			addClone(vmClone)
+
+			sanityExecute()
+			restore, err := client.SnapshotV1beta1().VirtualMachineRestores(metav1.NamespaceDefault).Get(context.TODO(), testRestoreName, metav1.GetOptions{})
+			Expect(err).ToNot(HaveOccurred())
+			Expect(restore.Spec.VirtualMachineSnapshotName).To(Equal(testSnapshotName))
+
+			expectedVM := sourceVM.DeepCopy()
+
+			// The new label must be present
+			expectedVM.Spec.Template.ObjectMeta.Labels = make(map[string]string)
+			expectedVM.Spec.Template.ObjectMeta.Labels["example"] = "extra-label"
+
+			// The deleted label must be absent
+			delete(expectedVM.Spec.Template.ObjectMeta.Labels, "label-to-remove")
+
+			// Architecture has been changed
+			expectedVM.Spec.Template.Spec.Architecture = "new-architecture"
+
+			expectVMCreationFromPatches(expectedVM)
+		})
+
+		It("Custom patches should override other patches", func() {
+			const interfaceName = "test-interface"
+			const newMacAddress = "AA-BB-CC-DD-EE-FF"
+			var newSMBiosSerial = "new-serial"
+
+			// Set a firmware UUID and a MAC address on the first interface of the VM
+			sourceVM.Spec.Template.Spec.Domain.Firmware = &virtv1.Firmware{Serial: "initial-serial"}
+			interfaces := sourceVM.Spec.Template.Spec.Domain.Devices.Interfaces
+			Expect(interfaces).To(HaveLen(1))
+			interfaces[0].Name = interfaceName
+			interfaces[0].MacAddress = "DE-AD-00-00-BE-EF"
+
+			// Use the Clone API to override SMBios/MAC address, but we expect this to do nothing
+			// as custom patches should have precedence over API defined patches.
+			vmClone.Spec.NewSMBiosSerial = &newSMBiosSerial
+			vmClone.Spec.NewMacAddresses = map[string]string{interfaceName: newMacAddress}
+
+			// Patches with higher precedence than any other in the VirtualMachineClone specs
+			patchSet := patch.New(
+				patch.WithReplace("/spec/template/spec/domain/firmware/serial", "replaced-serial"),
+				patch.WithReplace("/spec/template/spec/domain/devices/interfaces/0/macAddress", "DE-AD-00-FF-FF-FF"),
+			)
+
+			var err error
+			vmClone.Spec.Patches, err = patchSet.ToSlice()
+			Expect(err).NotTo(HaveOccurred())
+
+			addVM(sourceVM)
+			addClone(vmClone)
+
+			sanityExecute()
+			restore, err := client.SnapshotV1beta1().VirtualMachineRestores(metav1.NamespaceDefault).Get(context.TODO(), testRestoreName, metav1.GetOptions{})
+			Expect(err).ToNot(HaveOccurred())
+			Expect(restore.Spec.VirtualMachineSnapshotName).To(Equal(testSnapshotName))
+
+			expectedVM := sourceVM.DeepCopy()
+			expectedVM.Spec.Template.Spec.Domain.Firmware = &virtv1.Firmware{Serial: "replaced-serial"}
+			expectedVM.Spec.Template.Spec.Domain.Devices.Interfaces[0].MacAddress = "DE-AD-00-FF-FF-FF"
+			expectVMCreationFromPatches(expectedVM)
+		})
+
 		Context("Firmware UUID", func() {
 			const sourceFakeUUID = "source-fake-uuid"
 
@@ -1030,6 +1182,7 @@ func createVirtualMachineSnapshotContent(vm *virtv1.VirtualMachine) *snapshotv1.
 					Status:     vm.Status,
 				},
 			},
+			VirtualMachineSnapshotName: pointer.P(testSnapshotName),
 		},
 	}
 }
