@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
- * Copyright The KubeVirt Authors
+ * Copyright The KubeVirt Authors.
  *
  */
 package common
@@ -27,4 +27,6 @@ const (
 	FailedDeleteVirtualMachineReason = "FailedDelete"
 	// SuccessfulDeleteVirtualMachineReason when a virtual machine is successfully deleted.
 	SuccessfulDeleteVirtualMachineReason = "SuccessfulDelete"
+	// FailedUpdateVirtualMachineReason when a virtual machine is failed to be updated.
+	FailedUpdateVirtualMachineReason = "FailedUpdate"
 )
