@@ -26,14 +26,10 @@ import (
 	k8sv1 "k8s.io/api/core/v1"
 	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/types"
-	"k8s.io/client-go/tools/cache"
-
-	virtv1 "kubevirt.io/api/core/v1"
 	"kubevirt.io/client-go/kubecli"
 	"kubevirt.io/client-go/log"
 
 	"kubevirt.io/kubevirt/pkg/apimachinery/patch"
-	"kubevirt.io/kubevirt/pkg/controller"
 )
 
 // EvictOnlyAnnotation indicates pods whose eviction is not expected to be completed right away.
@@ -48,65 +44,51 @@ const EvictionInProgressAnnotation = "descheduler.alpha.kubernetes.io/eviction-i
 // The descheduler will only check the presence of the annotation and not its value.
 const EvictPodAnnotationKeyAlpha = "descheduler.alpha.kubernetes.io/evict"
 
-// EvictPodAnnotationKeyBeta can be used to explicitly opt-in/out a pod to be eventually descheduled.
-// The descheduler will check the annotation value with a Boolean logic.
-const EvictPodAnnotationKeyBeta = "descheduler.beta.kubernetes.io/evict"
+// EvictPodAnnotationKeyAlphaPreferNoEviction can be used to explicitly opt-out a pod to be eventually descheduled.
+// The descheduler will only check the presence of the annotation and not its value.
+const EvictPodAnnotationKeyAlphaPreferNoEviction = "descheduler.alpha.kubernetes.io/prefer-no-eviction"
 
-func MarkEvictionInProgress(virtClient kubecli.KubevirtClient, sourcePod *k8sv1.Pod) error {
+func MarkEvictionInProgress(virtClient kubecli.KubevirtClient, sourcePod *k8sv1.Pod) (*k8sv1.Pod, error) {
 	if _, exists := sourcePod.GetAnnotations()[EvictionInProgressAnnotation]; exists {
-		return nil
+		return sourcePod, nil
 	}
 
 	patchSet := patch.New(
-		patch.WithAdd(fmt.Sprintf("/metadata/annotations/%s", patch.EscapeJSONPointer(EvictionInProgressAnnotation)), "kubevirt"),
+		patch.WithAdd(fmt.Sprintf("/metadata/annotations/%s", patch.EscapeJSONPointer(EvictionInProgressAnnotation)), "true"),
 	)
 	patchBytes, err := patchSet.GeneratePayload()
 	if err != nil {
-		return err
+		return nil, err
 	}
 
-	_, err = virtClient.CoreV1().Pods(sourcePod.Namespace).Patch(context.Background(), sourcePod.Name, types.JSONPatchType, patchBytes, v1.PatchOptions{})
+	pod, err := virtClient.CoreV1().Pods(sourcePod.Namespace).Patch(context.Background(), sourcePod.Name, types.JSONPatchType, patchBytes, v1.PatchOptions{})
 	if err != nil {
 		log.Log.Object(sourcePod).Errorf("failed to add %s pod annotation: %v", EvictionInProgressAnnotation, err)
-		return err
+		return nil, err
 	}
 
-	return nil
+	return pod, nil
 }
 
-func MarkSourcePodEvictionCompleted(virtClient kubecli.KubevirtClient, migration *virtv1.VirtualMachineInstanceMigration, podIndexer cache.Indexer) error {
-	if migration.Status.MigrationState == nil || migration.Status.MigrationState.SourcePod == "" {
-		return nil
-	}
+func MarkEvictionCompleted(virtClient kubecli.KubevirtClient, sourcePod *k8sv1.Pod) (*k8sv1.Pod, error) {
 
-	podKey := controller.NamespacedKey(migration.Namespace, migration.Status.MigrationState.SourcePod)
-	obj, exists, err := podIndexer.GetByKey(podKey)
-	if !exists {
-		log.Log.Warningf("source pod %s does not exist", migration.Status.MigrationState.SourcePod)
-		return nil
-	}
-	if err != nil {
-		log.Log.Reason(err).Errorf("Failed to fetch source pod %s for namespace from cache.", migration.Status.MigrationState.SourcePod)
-		return err
-	}
-
-	sourcePod := obj.(*k8sv1.Pod)
-	if _, exists := sourcePod.GetAnnotations()[EvictionInProgressAnnotation]; exists {
+	if value, exists := sourcePod.GetAnnotations()[EvictionInProgressAnnotation]; exists {
 		patchSet := patch.New(
-			patch.WithTest(fmt.Sprintf("/metadata/annotations/%s", patch.EscapeJSONPointer(EvictionInProgressAnnotation)), "kubevirt"),
+			patch.WithTest(fmt.Sprintf("/metadata/annotations/%s", patch.EscapeJSONPointer(EvictionInProgressAnnotation)), value),
 			patch.WithRemove(fmt.Sprintf("/metadata/annotations/%s", patch.EscapeJSONPointer(EvictionInProgressAnnotation))),
 		)
 		patchBytes, err := patchSet.GeneratePayload()
 		if err != nil {
-			return err
+			return nil, err
 		}
 
-		_, err = virtClient.CoreV1().Pods(sourcePod.Namespace).Patch(context.Background(), sourcePod.Name, types.JSONPatchType, patchBytes, v1.PatchOptions{})
+		pod, err := virtClient.CoreV1().Pods(sourcePod.Namespace).Patch(context.Background(), sourcePod.Name, types.JSONPatchType, patchBytes, v1.PatchOptions{})
 		if err != nil {
 			log.Log.Object(sourcePod).Errorf("failed to remove %s pod annotation : %v", EvictionInProgressAnnotation, err)
-			return err
+			return nil, err
 		}
+		return pod, nil
 	}
 
-	return nil
+	return sourcePod, nil
 }
