@@ -21,6 +21,7 @@ package vmi
 
 import (
 	"context"
+	"encoding/json"
 	"errors"
 	"fmt"
 	"maps"
@@ -32,6 +33,7 @@ import (
 	k8serrors "k8s.io/apimachinery/pkg/api/errors"
 	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/types"
+	"k8s.io/apimachinery/pkg/util/strategicpatch"
 	k8sfield "k8s.io/apimachinery/pkg/util/validation/field"
 	"k8s.io/client-go/tools/cache"
 	"k8s.io/utils/trace"
@@ -185,6 +187,21 @@ func (c *Controller) sync(vmi *virtv1.VirtualMachineInstance, pod *k8sv1.Pod, da
 		}
 		pod = patchedPod
 
+		_, podIsMarkedForEviction := pod.GetAnnotations()[descheduler.EvictionInProgressAnnotation]
+		if vmi.IsMarkedForEviction() && !podIsMarkedForEviction {
+			patchedPod, err = descheduler.MarkEvictionInProgress(c.clientset, pod)
+			if err != nil {
+				return common.NewSyncError(err, controller.FailedPodPatchReason), pod
+			}
+		}
+		if !vmi.IsMarkedForEviction() && podIsMarkedForEviction {
+			patchedPod, err = descheduler.MarkEvictionCompleted(c.clientset, pod)
+			if err != nil {
+				return common.NewSyncError(err, controller.FailedPodPatchReason), pod
+			}
+		}
+		pod = patchedPod
+
 		hotplugVolumes := controller.GetHotplugVolumes(vmi, pod)
 		hotplugAttachmentPods, err := controller.AttachmentPods(pod, c.podIndexer)
 		if err != nil {
@@ -395,7 +412,7 @@ func (c *Controller) updateStatus(vmi *virtv1.VirtualMachineInstance, pod *k8sv1
 			return err
 		}
 
-		if allDeleted && (!vmi.IsDecentralizedMigration() || vmi.IsMigrationCompleted()) {
+		if allDeleted {
 			log.Log.V(3).Object(vmi).Infof("all pods have been deleted, removing finalizer")
 			controller.RemoveFinalizer(vmiCopy, virtv1.VirtualMachineInstanceFinalizer)
 			if vmiCopy.Labels != nil {
@@ -416,6 +433,11 @@ func (c *Controller) updateStatus(vmi *virtv1.VirtualMachineInstance, pod *k8sv1
 			break
 		}
 
+		if pod.Status.Phase == k8sv1.PodSucceeded && vmi.IsDecentralizedMigration() && vmi.Status.MigrationState != nil && vmi.Status.MigrationState.Completed {
+			vmiCopy.Status.Phase = virtv1.Succeeded
+			break
+		}
+
 		// Storage
 		if err := c.updateVolumeStatus(vmiCopy, pod); err != nil {
 			return err
@@ -442,6 +464,11 @@ func (c *Controller) updateStatus(vmi *virtv1.VirtualMachineInstance, pod *k8sv1
 
 	case vmi.IsScheduled():
 		if !vmiPodExists {
+			if vmiCopy.IsDecentralizedMigration() {
+				log.Log.Object(vmi).V(2).Infof("setting VMI to WaitingForSync while scheduled because pod does not exist")
+				vmiCopy.Status.Phase = virtv1.WaitingForSync
+				break
+			}
 			log.Log.Object(vmi).V(5).Infof("setting VMI to failed while scheduled because pod does not exist")
 			vmiCopy.Status.Phase = virtv1.Failed
 			break
@@ -641,7 +668,7 @@ func (c *Controller) syncDynamicAnnotationsAndLabelsToPod(vmi *virtv1.VirtualMac
 	)
 
 	syncMap(
-		[]string{descheduler.EvictPodAnnotationKeyAlpha, descheduler.EvictPodAnnotationKeyBeta},
+		[]string{descheduler.EvictPodAnnotationKeyAlpha, descheduler.EvictPodAnnotationKeyAlphaPreferNoEviction},
 		vmi.Annotations, newPodAnnotations, pod.ObjectMeta.Annotations, "annotations",
 	)
 
@@ -769,14 +796,14 @@ func (c *Controller) syncReadyConditionFromPod(vmi *virtv1.VirtualMachineInstanc
 	}
 }
 
-func (c *Controller) syncPausedConditionToPod(vmi *virtv1.VirtualMachineInstance, pod *k8sv1.Pod) error {
+func (c *Controller) syncPausedConditionToPod(vmi *virtv1.VirtualMachineInstance, originalPod *k8sv1.Pod) error {
 	vmiConditions := controller.NewVirtualMachineInstanceConditionManager()
 	podConditions := controller.NewPodConditionManager()
-	podCopy := pod.DeepCopy()
+	newPod := originalPod.DeepCopy()
 	now := v1.Now()
 	if vmiConditions.HasConditionWithStatus(vmi, virtv1.VirtualMachineInstancePaused, k8sv1.ConditionTrue) {
-		if podConditions.HasConditionWithStatus(pod, virtv1.VirtualMachineUnpaused, k8sv1.ConditionTrue) {
-			podConditions.UpdateCondition(podCopy, &k8sv1.PodCondition{
+		if podConditions.HasConditionWithStatus(originalPod, virtv1.VirtualMachineUnpaused, k8sv1.ConditionTrue) {
+			podConditions.UpdateCondition(newPod, &k8sv1.PodCondition{
 				Type:               virtv1.VirtualMachineUnpaused,
 				Status:             k8sv1.ConditionFalse,
 				Reason:             "Paused",
@@ -786,8 +813,8 @@ func (c *Controller) syncPausedConditionToPod(vmi *virtv1.VirtualMachineInstance
 			})
 		}
 	} else {
-		if !podConditions.HasConditionWithStatus(pod, virtv1.VirtualMachineUnpaused, k8sv1.ConditionTrue) {
-			podConditions.UpdateCondition(podCopy, &k8sv1.PodCondition{
+		if !podConditions.HasConditionWithStatus(originalPod, virtv1.VirtualMachineUnpaused, k8sv1.ConditionTrue) {
+			podConditions.UpdateCondition(newPod, &k8sv1.PodCondition{
 				Type:               virtv1.VirtualMachineUnpaused,
 				Status:             k8sv1.ConditionTrue,
 				Reason:             "NotPaused",
@@ -797,21 +824,25 @@ func (c *Controller) syncPausedConditionToPod(vmi *virtv1.VirtualMachineInstance
 			})
 		}
 	}
-	patchSet := preparePodPatch(pod, podCopy)
-	if patchSet.IsEmpty() {
+	if podConditions.ConditionsEqual(originalPod, newPod) {
 		return nil
 	}
-	patchBytes, err := patchSet.GeneratePayload()
+	originalBytes, err := json.Marshal(originalPod)
+	if err != nil {
+		return fmt.Errorf("could not serialize original object: %v", err)
+	}
+	modifiedBytes, err := json.Marshal(newPod)
+	patchBytes, err := strategicpatch.CreateTwoWayMergePatch(originalBytes, modifiedBytes, k8sv1.Pod{})
 	if err != nil {
 		return fmt.Errorf("error preparing pod patch: %v", err)
 	}
-	log.Log.V(3).Object(pod).Infof("Patching pod conditions")
-	_, err = c.clientset.CoreV1().Pods(pod.Namespace).Patch(context.TODO(), pod.Name, types.JSONPatchType, patchBytes, v1.PatchOptions{}, "status")
+	log.Log.V(3).Object(originalPod).Infof("Patching pod conditions")
+	_, err = c.clientset.CoreV1().Pods(originalPod.Namespace).Patch(context.TODO(), originalPod.Name, types.StrategicMergePatchType, patchBytes, v1.PatchOptions{}, "status")
 	// We could not retry if the "test" fails but we have no sane way to detect that right now:
 	// https://github.com/kubernetes/kubernetes/issues/68202 for details
 	// So just retry like with any other errors
 	if err != nil {
-		log.Log.Object(pod).Errorf("Patching of pod conditions failed: %v", err)
+		log.Log.Object(originalPod).Errorf("Patching of pod conditions failed: %v", err)
 		return fmt.Errorf("patching of pod conditions failed: %v", err)
 	}
 	return nil
@@ -1068,14 +1099,3 @@ func newMigrationRequiredCondition(status k8sv1.ConditionStatus) *virtv1.Virtual
 		Message:            "",
 	}
 }
-
-func preparePodPatch(oldPod, newPod *k8sv1.Pod) *patch.PatchSet {
-	podConditions := controller.NewPodConditionManager()
-	if podConditions.ConditionsEqual(oldPod, newPod) {
-		return patch.New()
-	}
-	return patch.New(
-		patch.WithTest("/status/conditions", oldPod.Status.Conditions),
-		patch.WithReplace("/status/conditions", newPod.Status.Conditions),
-	)
-}
