@@ -3,6 +3,7 @@ package workloadupdater
 import (
 	"context"
 	"fmt"
+	"strings"
 	"time"
 
 	. "github.com/onsi/ginkgo/v2"
@@ -14,6 +15,7 @@ import (
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/runtime"
 	"k8s.io/apimachinery/pkg/types"
+	k8svalidation "k8s.io/apimachinery/pkg/util/validation"
 	"k8s.io/client-go/kubernetes/fake"
 	k8stesting "k8s.io/client-go/testing"
 	"k8s.io/client-go/tools/cache"
@@ -65,7 +67,7 @@ var _ = Describe("Workload Updater", func() {
 
 	sanityExecute := func() {
 		controllertesting.SanityExecute(controller, []cache.Store{
-			controller.vmiStore, controller.podIndexer, controller.migrationStore, controller.kubeVirtStore,
+			controller.vmiStore, controller.podIndexer, controller.migrationIndexer, controller.kubeVirtStore,
 		}, Default)
 	}
 
@@ -87,7 +89,7 @@ var _ = Describe("Workload Updater", func() {
 				return []string{obj.(*v1.VirtualMachineInstance).Status.NodeName}, nil
 			},
 		})
-		migrationInformer, _ := testutils.NewFakeInformerFor(&v1.VirtualMachineInstanceMigration{})
+		migrationInformer, _ := testutils.NewFakeInformerWithIndexersFor(&v1.VirtualMachineInstanceMigration{}, virtcontroller.GetVirtualMachineInstanceMigrationInformerIndexers())
 		podInformer, _ := testutils.NewFakeInformerFor(&k8sv1.Pod{})
 		recorder = record.NewFakeRecorder(200)
 		recorder.IncludeObject = true
@@ -268,7 +270,7 @@ var _ = Describe("Workload Updater", func() {
 
 			By("populating with pending migrations that should be ignored while counting the threshold")
 			for i := 0; i < vmsPendingMigration; i++ {
-				controller.migrationStore.Add(newMigration(fmt.Sprintf("vmim-pending-%d", i), fmt.Sprintf("testvm-migratable-pending-%d", i), v1.MigrationPending))
+				controller.migrationIndexer.Add(newMigration(fmt.Sprintf("vmim-pending-%d", i), fmt.Sprintf("testvm-migratable-pending-%d", i), v1.MigrationPending))
 			}
 
 			var reasons []string
@@ -279,13 +281,13 @@ var _ = Describe("Workload Updater", func() {
 				controller.podIndexer.Add(pod)
 				// create enough migrations to only allow one more active one to be created
 				if i < int(virtconfig.ParallelMigrationsPerClusterDefault)-1 {
-					controller.migrationStore.Add(newMigration(fmt.Sprintf("vmim-%d", i), vmi.Name, v1.MigrationRunning))
+					controller.migrationIndexer.Add(newMigration(fmt.Sprintf("vmim-%d", i), vmi.Name, v1.MigrationRunning))
 				} else if i < int(virtconfig.ParallelMigrationsPerClusterDefault) {
-					controller.migrationStore.Add(newMigration(fmt.Sprintf("vmim-%d", i), vmi.Name, v1.MigrationSucceeded))
+					controller.migrationIndexer.Add(newMigration(fmt.Sprintf("vmim-%d", i), vmi.Name, v1.MigrationSucceeded))
 					// expect only a single migration to occur due to global limit
 					reasons = append(reasons, SuccessfulCreateVirtualMachineInstanceMigrationReason)
 				} else {
-					controller.migrationStore.Add(newMigration(fmt.Sprintf("vmim-%d", i), vmi.Name, v1.MigrationSucceeded))
+					controller.migrationIndexer.Add(newMigration(fmt.Sprintf("vmim-%d", i), vmi.Name, v1.MigrationSucceeded))
 				}
 			}
 
@@ -407,12 +409,12 @@ var _ = Describe("Workload Updater", func() {
 			pod := newLauncherPodForVMI(vmi)
 			controller.vmiStore.Add(vmi)
 			controller.podIndexer.Add(pod)
-			controller.migrationStore.Add(newMigration("vmim-1", vmi.Name, v1.MigrationRunning))
+			controller.migrationIndexer.Add(newMigration("vmim-1", vmi.Name, v1.MigrationRunning))
 			vmi = newVirtualMachineInstance("testvm-nonmigratable", false, "madeup")
 			pod = newLauncherPodForVMI(vmi)
 			controller.vmiStore.Add(vmi)
 			controller.podIndexer.Add(pod)
-			controller.migrationStore.Add(newMigration("vmim-2", vmi.Name, v1.MigrationRunning))
+			controller.migrationIndexer.Add(newMigration("vmim-2", vmi.Name, v1.MigrationRunning))
 
 			waitForNumberOfInstancesOnVMIInformerCache(controller, desiredNumberOfVMs)
 
@@ -552,7 +554,7 @@ var _ = Describe("Workload Updater", func() {
 		createMig := func(vmiName string, phase v1.VirtualMachineInstanceMigrationPhase) *v1.VirtualMachineInstanceMigration {
 			mig := newMigration("test", vmiName, phase)
 			mig.Annotations = map[string]string{v1.WorkloadUpdateMigrationAnnotation: ""}
-			controller.migrationStore.Add(mig)
+			controller.migrationIndexer.Add(mig)
 			_, err := fakeVirtClient.KubevirtV1().VirtualMachineInstanceMigrations(mig.Namespace).Create(context.Background(), mig, metav1.CreateOptions{})
 			Expect(err).ToNot(HaveOccurred())
 			return mig
@@ -658,6 +660,36 @@ var _ = Describe("Workload Updater", func() {
 		})
 	})
 
+	Context("workload volumes update", func() {
+		DescribeTable("should use correct label value for filtering", func(vmName, expectedLabelValue string) {
+			vmi := newVirtualMachineInstance(vmName, true, "madeup")
+			condition := v1.VirtualMachineInstanceCondition{
+				Type:   v1.VirtualMachineInstanceVolumesChange,
+				Status: k8sv1.ConditionTrue,
+			}
+			virtcontroller.NewVirtualMachineInstanceConditionManager().UpdateCondition(vmi, &condition)
+			pod := newLauncherPodForVMI(vmi)
+			kv := newKubeVirt(1)
+			kv.Spec.WorkloadUpdateStrategy.WorkloadUpdateMethods = []v1.WorkloadUpdateMethod{v1.WorkloadUpdateMethodLiveMigrate, v1.WorkloadUpdateMethodEvict}
+
+			addKubeVirt(kv)
+			controller.vmiStore.Add(vmi)
+			controller.podIndexer.Add(pod)
+			waitForNumberOfInstancesOnVMIInformerCache(controller, 1)
+
+			sanityExecute()
+			testutils.ExpectEvent(recorder, SuccessfulCreateVirtualMachineInstanceMigrationReason)
+			migrations, err := fakeVirtClient.KubevirtV1().VirtualMachineInstanceMigrations(k8sv1.NamespaceDefault).List(context.Background(), metav1.ListOptions{})
+			Expect(err).ToNot(HaveOccurred())
+			Expect(migrations.Items).To(HaveLen(1))
+			Expect(migrations.Items[0].Spec.VMIName).To(Equal(vmName))
+			Expect(migrations.Items[0].Labels[v1.VolumesUpdateMigration]).To(BeEquivalentTo(expectedLabelValue))
+		},
+			Entry("with regular name", "testvm", "testvm"),
+			Entry("with long name", strings.Repeat("a", k8svalidation.DNS1035LabelMaxLength+1), "1234"),
+		)
+	})
+
 	AfterEach(func() {
 		Expect(recorder.Events).To(BeEmpty())
 	})
