@@ -18,12 +18,15 @@ package arch
 
 import (
 	"fmt"
+	"strconv"
 
 	v1 "kubevirt.io/api/core/v1"
 
 	"kubevirt.io/kubevirt/pkg/pointer"
+	"kubevirt.io/kubevirt/pkg/util"
 	"kubevirt.io/kubevirt/pkg/virt-launcher/virtwrap/api"
 	"kubevirt.io/kubevirt/pkg/virt-launcher/virtwrap/device"
+	"kubevirt.io/kubevirt/pkg/virt-launcher/virtwrap/launchsecurity"
 )
 
 // Ensure that there is a compile error should the struct not implement the archConverter interface anymore.
@@ -126,3 +129,22 @@ func (converterAMD64) ConvertWatchdog(source *v1.Watchdog, watchdog *api.Watchdo
 	}
 	return fmt.Errorf("watchdog %s can't be mapped, no watchdog type specified", source.Name)
 }
+
+func (converterAMD64) SupportPCIHole64Disabling() bool {
+	return true
+}
+
+func (converterAMD64) LaunchSecurity(vmi *v1.VirtualMachineInstance) *api.LaunchSecurity {
+	// Set SEV launch security parameters: https://libvirt.org/formatdomain.html#launch-security
+	if util.IsSEVVMI(vmi) {
+		sevPolicyBits := launchsecurity.SEVPolicyToBits(vmi.Spec.Domain.LaunchSecurity.SEV.Policy)
+		// Cbitpos and ReducedPhysBits will be filled automatically by libvirt from the domain capabilities
+		return &api.LaunchSecurity{
+			Type:    "sev",
+			Policy:  "0x" + strconv.FormatUint(uint64(sevPolicyBits), 16),
+			DHCert:  vmi.Spec.Domain.LaunchSecurity.SEV.DHCert,
+			Session: vmi.Spec.Domain.LaunchSecurity.SEV.Session,
+		}
+	}
+	return nil
+}
