@@ -13,13 +13,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
- * Copyright 2019 Red Hat, Inc.
+ * Copyright The KubeVirt Authors.
  *
  */
 
 package apply
 
 import (
+	"context"
 	"crypto/tls"
 	"encoding/json"
 	"time"
@@ -29,18 +30,23 @@ import (
 	"k8s.io/client-go/testing"
 	"k8s.io/client-go/util/workqueue"
 
-	"github.com/golang/mock/gomock"
+	"go.uber.org/mock/gomock"
 	"k8s.io/client-go/tools/cache"
 
 	"kubevirt.io/client-go/kubecli"
 
 	"kubevirt.io/kubevirt/pkg/certificates/triple"
 	"kubevirt.io/kubevirt/pkg/certificates/triple/cert"
+	"kubevirt.io/kubevirt/pkg/controller"
+	"kubevirt.io/kubevirt/pkg/pointer"
+	"kubevirt.io/kubevirt/pkg/virt-config/featuregate"
 	"kubevirt.io/kubevirt/pkg/virt-operator/resource/generate/components"
 	"kubevirt.io/kubevirt/pkg/virt-operator/util"
 
+	networkv1 "github.com/k8snetworkplumbingwg/network-attachment-definition-client/pkg/apis/k8s.cni.cncf.io/v1"
 	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
+	coordinationv1 "k8s.io/api/coordination/v1"
 	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/util/intstr"
@@ -49,6 +55,33 @@ import (
 	v1 "kubevirt.io/api/core/v1"
 )
 
+const (
+	kubevirtNamespace                = "kubevirt"
+	synchronizationControllerPodName = "synchronization-controller"
+	networkAnnotationValue           = "lm-network@migration0"
+	networkStatusAnnotationValue     = `
+      [{
+          "name": "ovn-kubernetes",
+          "interface": "eth0",
+          "ips": [
+              "3.3.3.3",
+              "fd02:0:0:3::1844"
+          ],
+          "mac": "0a:58:0a:82:00:78",
+          "default": true,
+          "dns": {}
+      },{
+          "name": "kubevirt/lm-network",
+          "interface": "migration0",
+          "ips": [
+              "2.2.2.2"
+          ],
+          "mac": "a2:d1:5f:3a:d9:ea",
+          "dns": {}
+      }]
+	`
+)
+
 var _ = Describe("Apply", func() {
 
 	Context("Services", func() {
@@ -134,13 +167,20 @@ var _ = Describe("Apply", func() {
 			stores.ConfigMapCache = cache.NewStore(cache.DeletionHandlingMetaNamespaceKeyFunc)
 			stores.InstallStrategyConfigMapCache = cache.NewStore(cache.MetaNamespaceKeyFunc)
 
-			expectations = &util.Expectations{}
+			expectations = &util.Expectations{
+				ConfigMap: controller.NewUIDTrackingControllerExpectations(controller.NewControllerExpectationsWithName("ConfigMap")),
+			}
 
 			clientset = kubecli.NewMockKubevirtClient(ctrl)
 			clientset.EXPECT().KubeVirt(Namespace).Return(kvInterface).AnyTimes()
 			clientset.EXPECT().CoreV1().Return(coreclientset.CoreV1()).AnyTimes()
 
-			kv = &v1.KubeVirt{}
+			kv = &v1.KubeVirt{
+				ObjectMeta: metav1.ObjectMeta{
+					Name:      "kubevirt",
+					Namespace: operatorNamespace,
+				},
+			}
 		})
 
 		It("should not patch ConfigMap on sync", func() {
@@ -173,7 +213,7 @@ var _ = Describe("Apply", func() {
 				expectations: expectations,
 			}
 
-			_, err = r.createOrUpdateKubeVirtCAConfigMap(queue, crt, duration, requiredCM)
+			_, err = r.createOrUpdateKubeVirtCAConfigMap(queue, crt, nil, duration, requiredCM)
 			Expect(err).ToNot(HaveOccurred())
 		})
 
@@ -224,7 +264,7 @@ var _ = Describe("Apply", func() {
 
 			crt := createCrt()
 
-			_, err := r.createOrUpdateKubeVirtCAConfigMap(queue, crt, duration, requiredCM)
+			_, err := r.createOrUpdateKubeVirtCAConfigMap(queue, crt, nil, duration, requiredCM)
 			Expect(err).ToNot(HaveOccurred())
 			Expect(patched).To(BeTrue())
 		})
@@ -266,7 +306,89 @@ var _ = Describe("Apply", func() {
 
 			updatedCrt := createCrt()
 
-			_, err = r.createOrUpdateKubeVirtCAConfigMap(queue, updatedCrt, duration, requiredCM)
+			_, err = r.createOrUpdateKubeVirtCAConfigMap(queue, updatedCrt, nil, duration, requiredCM)
+			Expect(err).ToNot(HaveOccurred())
+			Expect(patched).To(BeTrue())
+		})
+
+		It("should create ConfigMap when it doesn't exist", func() {
+			requiredCMs := components.NewCAConfigMaps(operatorNamespace)
+			var requiredCM *corev1.ConfigMap
+			for _, cm := range requiredCMs {
+				if cm.Name == components.KubeVirtCASecretName {
+					requiredCM = cm
+				}
+			}
+			r := &Reconciler{
+				kv:           kv,
+				stores:       stores,
+				clientset:    clientset,
+				expectations: expectations,
+			}
+			created := false
+			coreclientset.Fake.PrependReactor("create", "configmaps", func(action testing.Action) (handled bool, ret runtime.Object, err error) {
+				created = true
+				return true, &corev1.ConfigMap{}, nil
+			})
+			updatedCrt := createCrt()
+			_, err := r.createOrUpdateKubeVirtCAConfigMap(queue, updatedCrt, nil, duration, requiredCM)
+			Expect(err).ToNot(HaveOccurred())
+			Expect(created).To(BeTrue())
+		})
+
+		It("should patch ConfigMap when external CA is added", func() {
+			requiredCMs := components.NewCAConfigMaps(operatorNamespace)
+			var requiredCM *corev1.ConfigMap
+			for _, cm := range requiredCMs {
+				if cm.Name == components.KubeVirtCASecretName {
+					requiredCM = cm
+				}
+			}
+			version, imageRegistry, id := getTargetVersionRegistryID(kv)
+			injectOperatorMetadata(kv, &requiredCMs[0].ObjectMeta, version, imageRegistry, id, true)
+
+			existingCM := requiredCM.DeepCopy()
+			crt := createCrt()
+
+			bundle, _, err := components.MergeCABundle(crt, []byte(cert.EncodeCertPEM(crt.Leaf)), time.Hour)
+			Expect(err).ToNot(HaveOccurred())
+
+			existingCM.Data = map[string]string{
+				components.CABundleKey: string(bundle),
+			}
+
+			stores.ConfigMapCache.Add(existingCM)
+
+			externalCrt := createCrt()
+			externalBundle, _, err := components.MergeCABundle(externalCrt, []byte(cert.EncodeCertPEM(externalCrt.Leaf)), time.Hour)
+			Expect(err).ToNot(HaveOccurred())
+			externalCM := &corev1.ConfigMap{
+				ObjectMeta: metav1.ObjectMeta{
+					Name:      components.ExternalKubeVirtCAConfigMapName,
+					Namespace: kv.Namespace,
+				},
+				BinaryData: map[string][]byte{
+					components.CABundleKey: externalBundle,
+				},
+				Data: map[string]string{
+					components.CABundleKey: string(externalBundle),
+				},
+			}
+			stores.ConfigMapCache.Add(externalCM)
+
+			r := &Reconciler{
+				kv:           kv,
+				stores:       stores,
+				clientset:    clientset,
+				expectations: expectations,
+			}
+			externalCACerts := r.getRemotePublicCas()
+			patched := false
+			coreclientset.Fake.PrependReactor("patch", "configmaps", func(action testing.Action) (handled bool, ret runtime.Object, err error) {
+				patched = true
+				return true, &corev1.ConfigMap{}, nil
+			})
+			_, err = r.createOrUpdateKubeVirtCAConfigMap(queue, crt, externalCACerts, duration, requiredCM)
 			Expect(err).ToNot(HaveOccurred())
 			Expect(patched).To(BeTrue())
 		})
@@ -737,4 +859,168 @@ var _ = Describe("Apply", func() {
 				}),
 		)
 	})
+
+	Context("update synchronization address when lease changes", func() {
+		var (
+			kubevirtClient *kubecli.MockKubevirtClient
+			reconciler     *Reconciler
+			kv             *v1.KubeVirt
+			stores         util.Stores
+			clientset      *fake.Clientset
+		)
+
+		BeforeEach(func() {
+			ctrl := gomock.NewController(GinkgoT())
+			clientset = fake.NewSimpleClientset()
+
+			stores = util.Stores{}
+			stores.ConfigMapCache = cache.NewStore(cache.DeletionHandlingMetaNamespaceKeyFunc)
+			stores.InstallStrategyConfigMapCache = cache.NewStore(cache.MetaNamespaceKeyFunc)
+
+			expectations := &util.Expectations{}
+			kv = &v1.KubeVirt{
+				ObjectMeta: metav1.ObjectMeta{
+					Name:      "kubevirt",
+					Namespace: "kubevirt",
+				},
+				Spec: v1.KubeVirtSpec{
+					Configuration: v1.KubeVirtConfiguration{
+						DeveloperConfiguration: &v1.DeveloperConfiguration{
+							FeatureGates: []string{
+								featuregate.DecentralizedLiveMigration,
+							},
+						},
+					},
+				},
+				Status: v1.KubeVirtStatus{},
+			}
+			kvInterface := kubecli.NewMockKubeVirtInterface(ctrl)
+
+			kubevirtClient = kubecli.NewMockKubevirtClient(ctrl)
+			kubevirtClient.EXPECT().KubeVirt(Namespace).Return(kvInterface).AnyTimes()
+			kubevirtClient.EXPECT().CoreV1().Return(clientset.CoreV1()).AnyTimes()
+			kubevirtClient.EXPECT().CoordinationV1().Return(clientset.CoordinationV1()).AnyTimes()
+
+			reconciler = &Reconciler{
+				kv:           kv,
+				stores:       stores,
+				clientset:    kubevirtClient,
+				expectations: expectations,
+			}
+		})
+		createLease := func(holder string) *coordinationv1.Lease {
+			return &coordinationv1.Lease{
+				ObjectMeta: metav1.ObjectMeta{
+					Name:      components.VirtSynchronizationControllerName,
+					Namespace: kubevirtNamespace,
+				},
+				Spec: coordinationv1.LeaseSpec{
+					HolderIdentity: pointer.P(holder),
+				},
+			}
+		}
+
+		It("should not populate synchronization address, if feature gate disabled", func() {
+			kv.Spec.Configuration.DeveloperConfiguration.FeatureGates = []string{}
+			Expect(kv.Status.SynchronizationAddresses).To(BeNil())
+			err := reconciler.updateSynchronizationAddress()
+			Expect(err).ToNot(HaveOccurred())
+			Expect(kv.Status.SynchronizationAddresses).To(BeNil())
+		})
+
+		It("should not populate synchronization address, if no lease found", func() {
+			Expect(kv.Status.SynchronizationAddresses).To(BeNil())
+			err := reconciler.updateSynchronizationAddress()
+			Expect(err).ToNot(HaveOccurred())
+			Expect(kv.Status.SynchronizationAddresses).To(BeNil())
+		})
+
+		It("should not populate synchronization address, if lease has no holder", func() {
+			lease := createLease("")
+			lease.Spec.HolderIdentity = nil
+			lease, err := clientset.CoordinationV1().Leases(kubevirtNamespace).Create(context.Background(), lease, metav1.CreateOptions{})
+			Expect(err).ToNot(HaveOccurred())
+			Expect(kv.Status.SynchronizationAddresses).To(BeNil())
+			err = reconciler.updateSynchronizationAddress()
+			Expect(err).ToNot(HaveOccurred())
+			Expect(kv.Status.SynchronizationAddresses).To(BeNil())
+		})
+
+		DescribeTable("update kubevirt synchronization address", func(synchronizationPod *corev1.Pod, port, expectedAddress string) {
+			lease := createLease(synchronizationControllerPodName)
+			lease, err := clientset.CoordinationV1().Leases(kubevirtNamespace).Create(context.Background(), lease, metav1.CreateOptions{})
+			Expect(err).ToNot(HaveOccurred())
+			if port != "" {
+				kv.Spec.SynchronizationPort = port
+			}
+			if synchronizationPod != nil {
+				synchronizationPod, err = clientset.CoreV1().Pods(kubevirtNamespace).Create(context.Background(), synchronizationPod, metav1.CreateOptions{})
+				Expect(kv.Status.SynchronizationAddresses).To(BeNil())
+			}
+			err = reconciler.updateSynchronizationAddress()
+			Expect(err).ToNot(HaveOccurred())
+			if expectedAddress != "" {
+				Expect(kv.Status.SynchronizationAddresses).ToNot(BeNil())
+				Expect(kv.Status.SynchronizationAddresses[0]).To(Equal(expectedAddress))
+			} else {
+				Expect(kv.Status.SynchronizationAddresses).To(BeNil())
+			}
+		},
+			Entry("should not populate synchronization address, if no pod found", nil, "", ""),
+			Entry("if pod found without migration network, without ip address", &corev1.Pod{
+				ObjectMeta: metav1.ObjectMeta{
+					Name:      synchronizationControllerPodName,
+					Namespace: kubevirtNamespace,
+				},
+				Status: corev1.PodStatus{},
+			}, "", ""),
+			Entry("if pod found without migration network, but with ip address", &corev1.Pod{
+				ObjectMeta: metav1.ObjectMeta{
+					Name:      synchronizationControllerPodName,
+					Namespace: kubevirtNamespace,
+				},
+				Status: corev1.PodStatus{
+					PodIPs: []corev1.PodIP{
+						{
+							IP: "1.1.1.1",
+						},
+					},
+				},
+			}, "", "1.1.1.1:9185"),
+			Entry("if pod found with migration network, use the migration ip address", &corev1.Pod{
+				ObjectMeta: metav1.ObjectMeta{
+					Name:      synchronizationControllerPodName,
+					Namespace: kubevirtNamespace,
+					Annotations: map[string]string{
+						networkv1.NetworkAttachmentAnnot: networkAnnotationValue,
+						networkv1.NetworkStatusAnnot:     networkStatusAnnotationValue,
+					},
+				},
+				Status: corev1.PodStatus{
+					PodIPs: []corev1.PodIP{
+						{
+							IP: "1.1.1.1",
+						},
+					},
+				},
+			}, "", "2.2.2.2:9185"),
+			Entry("if pod found with migration network, use the migration ip address, and defined port", &corev1.Pod{
+				ObjectMeta: metav1.ObjectMeta{
+					Name:      synchronizationControllerPodName,
+					Namespace: kubevirtNamespace,
+					Annotations: map[string]string{
+						networkv1.NetworkAttachmentAnnot: networkAnnotationValue,
+						networkv1.NetworkStatusAnnot:     networkStatusAnnotationValue,
+					},
+				},
+				Status: corev1.PodStatus{
+					PodIPs: []corev1.PodIP{
+						{
+							IP: "1.1.1.1",
+						},
+					},
+				},
+			}, "1234", "2.2.2.2:1234"),
+		)
+	})
 })
