@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
- * Copyright 2019 Red Hat, Inc.
+ * Copyright The KubeVirt Authors.
  *
  */
 package csv
@@ -39,38 +39,40 @@ import (
 const xDescriptorText = "urn:alm:descriptor:text"
 
 type NewClusterServiceVersionData struct {
-	Namespace             string
-	KubeVirtVersion       string
-	OperatorImageVersion  string
-	DockerPrefix          string
-	ImagePrefix           string
-	ImagePullPolicy       string
-	Verbosity             string
-	CsvVersion            string
-	VirtApiSha            string
-	VirtControllerSha     string
-	VirtHandlerSha        string
-	VirtLauncherSha       string
-	VirtExportProxySha    string
-	VirtExportServerSha   string
-	GsSha                 string
-	PrHelperSha           string
-	SidecarShimSha        string
-	RunbookURLTemplate    string
-	Replicas              int
-	IconBase64            string
-	ReplacesCsvVersion    string
-	CreatedAtTimestamp    string
-	VirtOperatorImage     string
-	VirtApiImage          string
-	VirtControllerImage   string
-	VirtHandlerImage      string
-	VirtLauncherImage     string
-	VirtExportProxyImage  string
-	VirtExportServerImage string
-	GsImage               string
-	PrHelperImage         string
-	SidecarShimImage      string
+	Namespace                          string
+	KubeVirtVersion                    string
+	OperatorImageVersion               string
+	DockerPrefix                       string
+	ImagePrefix                        string
+	ImagePullPolicy                    string
+	Verbosity                          string
+	CsvVersion                         string
+	VirtApiSha                         string
+	VirtControllerSha                  string
+	VirtHandlerSha                     string
+	VirtLauncherSha                    string
+	VirtExportProxySha                 string
+	VirtExportServerSha                string
+	VirtSynchronizationControllerSha   string
+	GsSha                              string
+	PrHelperSha                        string
+	SidecarShimSha                     string
+	RunbookURLTemplate                 string
+	Replicas                           int
+	IconBase64                         string
+	ReplacesCsvVersion                 string
+	CreatedAtTimestamp                 string
+	VirtOperatorImage                  string
+	VirtApiImage                       string
+	VirtControllerImage                string
+	VirtHandlerImage                   string
+	VirtLauncherImage                  string
+	VirtExportProxyImage               string
+	VirtExportServerImage              string
+	VirtSynchronizationControllerImage string
+	GsImage                            string
+	PrHelperImage                      string
+	SidecarShimImage                   string
 }
 
 type csvClusterPermissions struct {
@@ -172,6 +174,7 @@ func NewClusterServiceVersion(data *NewClusterServiceVersionData) (*csvv1.Cluste
 		data.VirtLauncherSha,
 		data.VirtExportProxySha,
 		data.VirtExportServerSha,
+		data.VirtSynchronizationControllerSha,
 		data.GsSha,
 		data.PrHelperSha,
 		data.SidecarShimSha,
@@ -182,6 +185,7 @@ func NewClusterServiceVersion(data *NewClusterServiceVersionData) (*csvv1.Cluste
 		data.VirtLauncherImage,
 		data.VirtExportProxyImage,
 		data.VirtExportServerImage,
+		data.VirtSynchronizationControllerImage,
 		data.GsImage,
 		data.PrHelperImage,
 		data.SidecarShimImage,
