@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
- * Copyright 2019 Red Hat, Inc.
+ * Copyright The KubeVirt Authors.
  *
  */
 package rbac
@@ -331,6 +331,7 @@ func getKubeVirtComponentsClusterRules() []rbacv1.PolicyRule {
 	all = append(all, GetAllController("")...)
 	all = append(all, GetAllHandler("")...)
 	all = append(all, GetAllExportProxy("")...)
+	all = append(all, GetAllSynchronizationController("")...)
 	all = append(all, GetAllCluster()...)
 
 	for _, resource := range all {
@@ -381,6 +382,7 @@ func getKubeVirtComponentsRules() []rbacv1.PolicyRule {
 	all = append(all, GetAllController("")...)
 	all = append(all, GetAllHandler("")...)
 	all = append(all, GetAllExportProxy("")...)
+	all = append(all, GetAllSynchronizationController("")...)
 	all = append(all, GetAllCluster()...)
 
 	for _, resource := range all {
@@ -480,6 +482,8 @@ func NewOperatorRole(namespace string) *rbacv1.Role {
 					components.VirtApiCertSecretName,
 					components.VirtControllerCertSecretName,
 					components.VirtExportProxyCertSecretName,
+					components.VirtSynchronizationControllerCertSecretName,
+					components.VirtSynchronizationControllerServerCertSecretName,
 				},
 				Verbs: []string{
 					"create",
