@@ -21,36 +21,37 @@ func VersionCommand() *cobra.Command {
 		Use:     "version",
 		Short:   "Print the client and server version information.",
 		Example: usage(),
-		Args:    cobra.ExactArgs(0),
+		Args:    cobra.NoArgs,
 		RunE:    v.Run,
 	}
 	cmd.Flags().BoolVarP(&v.clientOnly, "client", "c", v.clientOnly, "Client version only (no server required).")
 	cmd.SetUsageTemplate(templates.UsageTemplate())
+
 	return cmd
 }
 
 func usage() string {
-	usage := "  # Print the client and server versions for the current context:\n"
-	usage += "  {{ProgramName}} version"
-	return usage
+	return `  # Print the client and server versions for the current context:
+  {{ProgramName}} version`
 }
 
 func (v *version) Run(cmd *cobra.Command, _ []string) error {
-	cmd.Printf("Client Version: %s\n", fmt.Sprintf("%#v", client_version.Get()))
+	cmd.Printf("Client Version: %#v\n", client_version.Get())
 
-	if !v.clientOnly {
-		virCli, _, _, err := clientconfig.ClientAndNamespaceFromContext(cmd.Context())
-		if err != nil {
-			return err
-		}
-
-		serverInfo, err := virCli.ServerVersion().Get()
-		if err != nil {
-			return err
-		}
-
-		cmd.Printf("Server Version: %s\n", fmt.Sprintf("%#v", *serverInfo))
+	if v.clientOnly {
+		return nil
 	}
 
+	virtClient, _, _, err := clientconfig.ClientAndNamespaceFromContext(cmd.Context())
+	if err != nil {
+		return fmt.Errorf("failed to get virtClient config: %w", err)
+	}
+
+	serverInfo, err := virtClient.ServerVersion().Get()
+	if err != nil {
+		return fmt.Errorf("failed to get server version: %w", err)
+	}
+
+	cmd.Printf("Server Version: %#v\n", *serverInfo)
 	return nil
 }
