@@ -9,27 +9,25 @@ import (
 
 var containerTag = ""
 
-func done(files []string) {
-	err := os.WriteFile("/tmp/sonobuoy/results/done", []byte(strings.Join(files, "\n")), 0666)
-	if err != nil {
-		fmt.Printf("Failed to notify sonobuoy that I am done: %v\n", err)
-	}
-}
+const resultsDir = "/tmp/sonobuoy/results"
 
 func main() {
 	err := execute()
-	done([]string{
-		"/tmp/sonobuoy/results",
-	})
 	if err != nil {
+		fmt.Printf("Failed to execute conformance suite: %v\n", err)
+		os.Exit(1)
+	}
+
+	const writeFilePerms = 0o666
+	err = os.WriteFile(fmt.Sprintf("%s/done", resultsDir), []byte(strings.Join([]string{resultsDir}, "\n")), writeFilePerms)
+	if err != nil {
+		fmt.Printf("Failed to notify sonobuoy that I am done: %v\n", err)
 		os.Exit(1)
 	}
 }
 
 func execute() error {
-	args := []string{}
-	args = append(args, "--container-tag", containerTag)
-	args = append(args, "--junit-output", "/tmp/sonobuoy/results/junit.xml")
+	args := []string{"--container-tag", containerTag, "--junit-output", fmt.Sprintf("%s/junit.xml", resultsDir)}
 	// additional conformance test overrides
 	if value, exists := os.LookupEnv("E2E_SKIP"); exists {
 		args = append(args, "--ginkgo.skip", value)
@@ -56,14 +54,9 @@ func execute() error {
 
 	cmd := exec.Command("/usr/bin/go_default_test", args...)
 	cmd.Env = os.Environ()
-	cmd.Env = append(cmd.Env, "ARTIFACTS=/tmp/sonobuoy/results/")
+	cmd.Env = append(cmd.Env, fmt.Sprintf("ARTIFACTS=%s", resultsDir))
 	cmd.Stderr = os.Stderr
 	cmd.Stdin = os.Stdin
 	cmd.Stdout = os.Stdout
-	err := cmd.Run()
-	if err != nil {
-		fmt.Printf("command failed with %v\n", err)
-		return err
-	}
-	return nil
+	return cmd.Run()
 }
