@@ -55,11 +55,21 @@ func HaveConditionFalseWithMessage(conditionType interface{}, expectedMessage st
 	}
 }
 
+func HaveConditionTrueWithReason(conditionType interface{}, expectedReason string) types.GomegaMatcher {
+	return conditionMatcher{
+		expectedType:          conditionType,
+		expectedStatus:        k8sv1.ConditionTrue,
+		conditionCanBeMissing: false,
+		expectedReason:        expectedReason,
+	}
+}
+
 type conditionMatcher struct {
 	expectedType          interface{}
 	expectedStatus        k8sv1.ConditionStatus
 	conditionCanBeMissing bool
 	expectedMessage       string
+	expectedReason        string
 }
 
 func (c conditionMatcher) Match(actual interface{}) (success bool, err error) {
@@ -107,10 +117,28 @@ func (c conditionMatcher) Match(actual interface{}) (success bool, err error) {
 		return false, nil
 	}
 
-	if c.expectedMessage == "" {
-		return true, nil
+	if c.expectedMessage != "" {
+		return c.checkMessage(conditions)
 	}
 
+	if c.expectedReason != "" {
+		return c.checkReason(conditions)
+	}
+	return true, nil
+}
+
+func (c conditionMatcher) checkReason(conditions []interface{}) (bool, error) {
+	conditionReason, err := c.getReasonForExpectedConditionType(conditions)
+	if err != nil {
+		return false, err
+	}
+	if conditionReason == "" {
+		return c.conditionCanBeMissing, nil
+	}
+	return conditionReason == c.expectedReason, nil
+}
+
+func (c conditionMatcher) checkMessage(conditions []interface{}) (bool, error) {
 	conditionMessage, err := c.getMessageForExpectedConditionType(conditions)
 	if err != nil {
 		return false, err
@@ -166,6 +194,31 @@ func (c conditionMatcher) FailureMessage(actual interface{}) string {
 		return format.Message(conditions, fmt.Sprintf("to find condition of type '%v' and status '%s' but got '%s'", c.expectedType, c.expectedStatus, conditionStatus))
 	}
 
+	if c.expectedMessage != "" {
+		return c.messageFailure(conditions)
+	}
+
+	if c.expectedReason != "" {
+		return c.reasonFailure(conditions)
+	}
+	return ""
+}
+
+func (c conditionMatcher) reasonFailure(conditions []interface{}) string {
+	conditionReason, err := c.getReasonForExpectedConditionType(conditions)
+	if err != nil {
+		return err.Error()
+	}
+	if conditionReason == "" {
+		if c.conditionCanBeMissing {
+			return ""
+		}
+		return format.Message(conditions, fmt.Sprintf("expected condition of type '%s' had an empty reason", c.expectedType))
+	}
+	return format.Message(conditions, fmt.Sprintf("condition of type '%v' with status '%s' doesn't contain reason '%s' but instead '%s'", c.expectedType, c.expectedStatus, c.expectedReason, conditionReason))
+}
+
+func (c conditionMatcher) messageFailure(conditions []interface{}) string {
 	conditionMessage, err := c.getMessageForExpectedConditionType(conditions)
 	if err != nil {
 		return err.Error()
@@ -276,3 +329,7 @@ func (c conditionMatcher) getStatusForExpectedConditionType(conditions []interfa
 func (c conditionMatcher) getMessageForExpectedConditionType(conditions []interface{}) (status string, err error) {
 	return c.getValueForExpectedConditionType(conditions, "message")
 }
+
+func (c conditionMatcher) getReasonForExpectedConditionType(conditions []interface{}) (status string, err error) {
+	return c.getValueForExpectedConditionType(conditions, "reason")
+}
