@@ -4,6 +4,7 @@ import (
 	"fmt"
 	"reflect"
 
+	"github.com/onsi/gomega/format"
 	"github.com/onsi/gomega/types"
 
 	"kubevirt.io/kubevirt/tests/framework/matcher/helper"
@@ -13,10 +14,6 @@ func Exist() types.GomegaMatcher {
 	return existMatcher{}
 }
 
-func BePresent() types.GomegaMatcher {
-	return existMatcher{}
-}
-
 func BeGone() types.GomegaMatcher {
 	return goneMatcher{}
 }
@@ -31,12 +28,35 @@ func (e existMatcher) Match(actual interface{}) (success bool, err error) {
 	return true, nil
 }
 
+func formatObject(actual interface{}) string {
+	if helper.IsNil(actual) {
+		return fmt.Sprintf("%v", actual)
+	}
+	if !helper.IsStruct(helper.DeferPointer(actual)) {
+		return fmt.Sprintf("%v", actual)
+	}
+	obj := reflect.ValueOf(helper.ToPointer(actual)).Elem()
+	metadata := obj.FieldByName("ObjectMeta")
+	if metadata.IsZero() {
+		return fmt.Sprintf("%v", actual)
+	}
+
+	// Optional
+	status := obj.FieldByName("Status")
+
+	// Too much data to display and is only helpful in later stages
+	metadata.FieldByName("ManagedFields").SetZero()
+
+	return fmt.Sprintf("%s\nmetadata: %s \nstatus: %s", reflect.TypeOf(actual), format.Object(metadata.Interface(), 0), format.Object(status.Interface(), 0))
+}
+
 func (e existMatcher) FailureMessage(actual interface{}) (message string) {
-	return fmt.Sprintf("expected object to still exist, but it is gone: %v", actual)
+
+	return fmt.Sprintf("expected object to still exist, but it is gone: %s", formatObject(actual))
 }
 
 func (e existMatcher) NegatedFailureMessage(actual interface{}) (message string) {
-	return fmt.Sprintf("expected object to be gone, but it still exists: %v", actual)
+	return fmt.Sprintf("expected object to be gone, but it still exists: %s", formatObject(actual))
 }
 
 type goneMatcher struct {
@@ -53,9 +73,9 @@ func (g goneMatcher) Match(actual interface{}) (success bool, err error) {
 }
 
 func (g goneMatcher) FailureMessage(actual interface{}) (message string) {
-	return fmt.Sprintf("expected object to be gone, but it still exists: %v", actual)
+	return fmt.Sprintf("expected object to be gone, but it still exists: %s", formatObject(actual))
 }
 
 func (g goneMatcher) NegatedFailureMessage(actual interface{}) (message string) {
-	return fmt.Sprintf("expected object to still exist, but it is gone: %v", actual)
+	return fmt.Sprintf("expected object to still exist, but it is gone: %s", formatObject(actual))
 }
