@@ -16,6 +16,8 @@ import (
 	"kubevirt.io/containerized-data-importer-api/pkg/apis/core/v1beta1"
 )
 
+var getClient = kubevirt.Client
+
 // ThisPod fetches the latest state of the pod. If the object does not exist, nil is returned.
 func ThisPod(pod *v1.Pod) func() (*v1.Pod, error) {
 	return ThisPodWith(pod.Namespace, pod.Name)
@@ -23,15 +25,18 @@ func ThisPod(pod *v1.Pod) func() (*v1.Pod, error) {
 
 // ThisPodWith fetches the latest state of the pod based on namespace and name. If the object does not exist, nil is returned.
 func ThisPodWith(namespace string, name string) func() (*v1.Pod, error) {
-	return func() (p *v1.Pod, err error) {
-		virtClient := kubevirt.Client()
-		p, err = virtClient.CoreV1().Pods(namespace).Get(context.Background(), name, k8smetav1.GetOptions{})
-		if errors.IsNotFound(err) {
-			return nil, nil
+	return func() (*v1.Pod, error) {
+		virtClient := getClient()
+		p, err := virtClient.CoreV1().Pods(namespace).Get(context.Background(), name, k8smetav1.GetOptions{})
+		if err != nil {
+			if errors.IsNotFound(err) {
+				return nil, nil
+			}
+			return nil, err
 		}
-		//Since https://github.com/kubernetes/client-go/issues/861 we manually add the Kind
+		// Since https://github.com/kubernetes/client-go/issues/861 we manually add the Kind
 		p.Kind = "Pod"
-		return
+		return p, nil
 	}
 }
 
@@ -42,13 +47,16 @@ func ThisVMI(vmi *virtv1.VirtualMachineInstance) func() (*virtv1.VirtualMachineI
 
 // ThisVMIWith fetches the latest state of the VirtualMachineInstance based on namespace and name. If the object does not exist, nil is returned.
 func ThisVMIWith(namespace string, name string) func() (*virtv1.VirtualMachineInstance, error) {
-	return func() (p *virtv1.VirtualMachineInstance, err error) {
-		virtClient := kubevirt.Client()
-		p, err = virtClient.VirtualMachineInstance(namespace).Get(context.Background(), name, k8smetav1.GetOptions{})
-		if errors.IsNotFound(err) {
-			return nil, nil
+	return func() (*virtv1.VirtualMachineInstance, error) {
+		virtClient := getClient()
+		p, err := virtClient.VirtualMachineInstance(namespace).Get(context.Background(), name, k8smetav1.GetOptions{})
+		if err != nil {
+			if errors.IsNotFound(err) {
+				return nil, nil
+			}
+			return nil, err
 		}
-		return
+		return p, nil
 	}
 }
 
@@ -59,20 +67,23 @@ func ThisVM(vm *virtv1.VirtualMachine) func() (*virtv1.VirtualMachine, error) {
 
 // ThisVMWith fetches the latest state of the VirtualMachine based on namespace and name. If the object does not exist, nil is returned.
 func ThisVMWith(namespace string, name string) func() (*virtv1.VirtualMachine, error) {
-	return func() (p *virtv1.VirtualMachine, err error) {
-		virtClient := kubevirt.Client()
-		p, err = virtClient.VirtualMachine(namespace).Get(context.Background(), name, k8smetav1.GetOptions{})
-		if errors.IsNotFound(err) {
-			return nil, nil
+	return func() (*virtv1.VirtualMachine, error) {
+		virtClient := getClient()
+		p, err := virtClient.VirtualMachine(namespace).Get(context.Background(), name, k8smetav1.GetOptions{})
+		if err != nil {
+			if errors.IsNotFound(err) {
+				return nil, nil
+			}
+			return nil, err
 		}
-		return
+		return p, nil
 	}
 }
 
 // AllVMI fetches the latest state of all VMIs in a namespace.
 func AllVMIs(namespace string) func() ([]virtv1.VirtualMachineInstance, error) {
 	return func() (p []virtv1.VirtualMachineInstance, err error) {
-		virtClient := kubevirt.Client()
+		virtClient := getClient()
 		list, err := virtClient.VirtualMachineInstance(namespace).List(context.Background(), k8smetav1.ListOptions{})
 		return list.Items, err
 	}
@@ -80,7 +91,7 @@ func AllVMIs(namespace string) func() ([]virtv1.VirtualMachineInstance, error) {
 
 func AllPDBs(namespace string) func() ([]policyv1.PodDisruptionBudget, error) {
 	return func() (p []policyv1.PodDisruptionBudget, err error) {
-		virtClient := kubevirt.Client()
+		virtClient := getClient()
 		list, err := virtClient.PolicyV1().PodDisruptionBudgets(namespace).List(context.Background(), k8smetav1.ListOptions{})
 		return list.Items, err
 	}
@@ -93,15 +104,18 @@ func ThisDV(dv *v1beta1.DataVolume) func() (*v1beta1.DataVolume, error) {
 
 // ThisDVWith fetches the latest state of the DataVolume based on namespace and name. If the object does not exist, nil is returned.
 func ThisDVWith(namespace string, name string) func() (*v1beta1.DataVolume, error) {
-	return func() (p *v1beta1.DataVolume, err error) {
-		virtClient := kubevirt.Client()
-		p, err = virtClient.CdiClient().CdiV1beta1().DataVolumes(namespace).Get(context.Background(), name, k8smetav1.GetOptions{})
-		if errors.IsNotFound(err) {
-			return nil, nil
+	return func() (*v1beta1.DataVolume, error) {
+		virtClient := getClient()
+		p, err := virtClient.CdiClient().CdiV1beta1().DataVolumes(namespace).Get(context.Background(), name, k8smetav1.GetOptions{})
+		if err != nil {
+			if errors.IsNotFound(err) {
+				return nil, nil
+			}
+			return nil, err
 		}
 		//Since https://github.com/kubernetes/client-go/issues/861 we manually add the Kind
 		p.Kind = "DataVolume"
-		return
+		return p, nil
 	}
 }
 
@@ -112,15 +126,18 @@ func ThisPVC(pvc *v1.PersistentVolumeClaim) func() (*v1.PersistentVolumeClaim, e
 
 // ThisPVCWith fetches the latest state of the PersistentVolumeClaim based on namespace and name. If the object does not exist, nil is returned.
 func ThisPVCWith(namespace string, name string) func() (*v1.PersistentVolumeClaim, error) {
-	return func() (p *v1.PersistentVolumeClaim, err error) {
-		virtClient := kubevirt.Client()
-		p, err = virtClient.CoreV1().PersistentVolumeClaims(namespace).Get(context.Background(), name, k8smetav1.GetOptions{})
-		if errors.IsNotFound(err) {
-			return nil, nil
+	return func() (*v1.PersistentVolumeClaim, error) {
+		virtClient := getClient()
+		p, err := virtClient.CoreV1().PersistentVolumeClaims(namespace).Get(context.Background(), name, k8smetav1.GetOptions{})
+		if err != nil {
+			if errors.IsNotFound(err) {
+				return nil, nil
+			}
+			return nil, err
 		}
 		//Since https://github.com/kubernetes/client-go/issues/861 we manually add the Kind
 		p.Kind = "PersistentVolumeClaim"
-		return
+		return p, nil
 	}
 }
 
@@ -131,26 +148,32 @@ func ThisMigration(migration *virtv1.VirtualMachineInstanceMigration) func() (*v
 
 // ThisMigrationWith fetches the latest state of the Migration based on namespace and name. If the object does not exist, nil is returned.
 func ThisMigrationWith(namespace string, name string) func() (*virtv1.VirtualMachineInstanceMigration, error) {
-	return func() (p *virtv1.VirtualMachineInstanceMigration, err error) {
-		virtClient := kubevirt.Client()
-		p, err = virtClient.VirtualMachineInstanceMigration(namespace).Get(context.Background(), name, k8smetav1.GetOptions{})
-		if errors.IsNotFound(err) {
-			return nil, nil
+	return func() (*virtv1.VirtualMachineInstanceMigration, error) {
+		virtClient := getClient()
+		p, err := virtClient.VirtualMachineInstanceMigration(namespace).Get(context.Background(), name, k8smetav1.GetOptions{})
+		if err != nil {
+			if errors.IsNotFound(err) {
+				return nil, nil
+			}
+			return nil, err
 		}
-		return
+		return p, nil
 	}
 }
 
 // ThisDeploymentWith fetches the latest state of the Deployment based on namespace and name. If the object does not exist, nil is returned.
 func ThisDeploymentWith(namespace string, name string) func() (*k8sv1.Deployment, error) {
-	return func() (p *k8sv1.Deployment, err error) {
-		virtClient := kubevirt.Client()
-		p, err = virtClient.AppsV1().Deployments(namespace).Get(context.Background(), name, k8smetav1.GetOptions{})
-		if errors.IsNotFound(err) {
-			return nil, nil
+	return func() (*k8sv1.Deployment, error) {
+		virtClient := getClient()
+		p, err := virtClient.AppsV1().Deployments(namespace).Get(context.Background(), name, k8smetav1.GetOptions{})
+		if err != nil {
+			if errors.IsNotFound(err) {
+				return nil, nil
+			}
+			return nil, err
 		}
 		//Since https://github.com/kubernetes/client-go/issues/861 we manually add the Kind
 		p.Kind = "Deployment"
-		return
+		return p, nil
 	}
 }
