@@ -6,11 +6,6 @@ import (
 	"context"
 	"encoding/json"
 	"fmt"
-
-	"kubevirt.io/kubevirt/tests/libnode"
-
-	"k8s.io/client-go/util/flowcontrol"
-
 	"os"
 	"path/filepath"
 	"regexp"
@@ -19,6 +14,8 @@ import (
 	"strings"
 	"time"
 
+	"k8s.io/client-go/util/flowcontrol"
+
 	virt_chroot "kubevirt.io/kubevirt/pkg/virt-handler/virt-chroot"
 
 	expect "github.com/google/goexpect"
@@ -36,12 +33,13 @@ import (
 	"kubevirt.io/client-go/log"
 	apicdi "kubevirt.io/containerized-data-importer-api/pkg/apis/core/v1beta1"
 
-	"kubevirt.io/kubevirt/tests"
 	"kubevirt.io/kubevirt/tests/clientcmd"
 	"kubevirt.io/kubevirt/tests/console"
 	"kubevirt.io/kubevirt/tests/exec"
 	"kubevirt.io/kubevirt/tests/flags"
 	"kubevirt.io/kubevirt/tests/framework/checks"
+	"kubevirt.io/kubevirt/tests/libdomain"
+	"kubevirt.io/kubevirt/tests/libnode"
 	"kubevirt.io/kubevirt/tests/testsuite"
 )
 
@@ -278,7 +276,7 @@ func (r *KubernetesReporter) logDomainXMLs(virtCli kubecli.KubevirtClient, vmis
 		if vmi.IsFinal() {
 			continue
 		}
-		domxml, err := tests.GetRunningVirtualMachineInstanceDomainXML(virtCli, &vmi)
+		domxml, err := libdomain.GetRunningVirtualMachineInstanceDomainXML(virtCli, &vmi)
 		if err == nil {
 			fmt.Fprintln(f, domxml)
 		}
@@ -338,7 +336,7 @@ func (r *KubernetesReporter) logDMESG(virtCli kubecli.KubevirtClient, logsdir st
 			commands := []string{
 				virt_chroot.GetChrootBinaryPath(),
 				"--mount",
-				virt_chroot.GetChrootMountNamespace(),
+				virt_chroot.GetChrootNSMountPath(),
 				"exec",
 				"--",
 				"/proc/1/root/bin/dmesg",
@@ -459,9 +457,8 @@ func (r *KubernetesReporter) logVMICommands(virtCli kubecli.KubevirtClient, vmiN
 	}
 
 	for _, vmi := range runningVMIs {
-		vmiType, err := getVmiType(vmi)
-		if err != nil {
-			printError("skipping vmi %s/%s: failed to get vmi type: %v", vmi.Namespace, vmi.Name, err)
+		vmiType := getVmiType(vmi)
+		if vmiType == "" {
 			continue
 		}
 
@@ -483,9 +480,8 @@ func (r *KubernetesReporter) logCloudInit(virtCli kubecli.KubevirtClient, vmiNam
 	}
 
 	for _, vmi := range runningVMIs {
-		vmiType, err := getVmiType(vmi)
-		if err != nil {
-			printError("skipping vmi %s/%s: failed to get vmi type: %v", vmi.Namespace, vmi.Name, err)
+		vmiType := getVmiType(vmi)
+		if vmiType == "" {
 			continue
 		}
 
@@ -556,7 +552,7 @@ func (r *KubernetesReporter) logVirtLauncherCommands(virtCli kubecli.KubevirtCli
 		}
 
 		if !isContainerReady(pod.Status.ContainerStatuses, computeContainer) {
-			printError("could not find healty compute container for pod %s", pod.ObjectMeta.Name)
+			printError("could not find healthy compute container for pod %s", pod.ObjectMeta.Name)
 			continue
 		}
 
@@ -624,7 +620,7 @@ func (r *KubernetesReporter) logJournal(virtCli kubecli.KubevirtClient, logsdir
 		commands := []string{
 			virt_chroot.GetChrootBinaryPath(),
 			"--mount",
-			virt_chroot.GetChrootMountNamespace(),
+			virt_chroot.GetChrootNSMountPath(),
 			"exec",
 			"--",
 			"/usr/bin/journalctl",
@@ -901,7 +897,8 @@ func (r *KubernetesReporter) logLogs(virtCli kubecli.KubevirtClient, logsdir str
 	}
 
 	for _, pod := range pods.Items {
-		for _, container := range pod.Spec.Containers {
+		allContainers := append(pod.Spec.Containers, pod.Spec.InitContainers...)
+		for _, container := range allContainers {
 			current, err := os.OpenFile(filepath.Join(logsdir, fmt.Sprintf("%d_%s_%s-%s.log", r.failureCount, pod.Namespace, pod.Name, container.Name)), os.O_APPEND|os.O_CREATE|os.O_WRONLY, 0644)
 			if err != nil {
 				printError(failedOpenFileFmt, err)
@@ -991,14 +988,9 @@ func getRunningVMIs(virtCli kubecli.KubevirtClient, namespace []string) []v12.Vi
 				continue
 			}
 
-			vmiType, err := getVmiType(vmi)
-			if err != nil {
-				printError("skipping vmi %s/%s: failed to get vmi type: %v", vmi.Namespace, vmi.Name, err)
-				continue
-			}
+			vmiType := getVmiType(vmi)
 
-			if err := prepareVmiConsole(vmi, vmiType); err != nil {
-				printError("skipping vmi %s/%s: failed to login: %v", vmi.Namespace, vmi.Name, err)
+			if vmiType == "" || prepareVmiConsole(vmi, vmiType) != nil {
 				continue
 			}
 			runningVMIs = append(runningVMIs, vmi)
@@ -1131,16 +1123,7 @@ func (r *KubernetesReporter) dumpK8sEntityToFile(virtCli kubecli.KubevirtClient,
 }
 
 func (r *KubernetesReporter) logClusterOverview() {
-	binary := ""
-	if flags.KubeVirtKubectlPath != "" {
-		binary = "kubectl"
-	} else if flags.KubeVirtOcPath != "" {
-		binary = "oc"
-	} else {
-		return
-	}
-
-	stdout, stderr, err := clientcmd.RunCommand("", binary, "get", "all", "--all-namespaces", "-o", "wide")
+	stdout, stderr, err := clientcmd.RunCommand("", "kubectl", "get", "all", "--all-namespaces", "-o", "wide")
 	if err != nil {
 		printError("failed to fetch cluster overview: %v, %s", err, stderr)
 		return
@@ -1189,7 +1172,7 @@ func writeStringToFile(filePath string, data string) error {
 	return err
 }
 
-func getVmiType(vmi v12.VirtualMachineInstance) (string, error) {
+func getVmiType(vmi v12.VirtualMachineInstance) string {
 	for _, volume := range vmi.Spec.Volumes {
 		if volume.VolumeSource.ContainerDisk == nil {
 			continue
@@ -1197,19 +1180,15 @@ func getVmiType(vmi v12.VirtualMachineInstance) (string, error) {
 
 		image := volume.VolumeSource.ContainerDisk.Image
 		if strings.Contains(image, "fedora") {
-			return "fedora", nil
+			return "fedora"
 		} else if strings.Contains(image, "cirros") {
-			return "cirros", nil
+			return "cirros"
 		} else if strings.Contains(image, "alpine") {
-			return "alpine", nil
+			return "alpine"
 		}
 	}
 
-	if vmiJson, err := json.Marshal(vmi); err == nil {
-		return "", fmt.Errorf("unknown type, vmi %s", vmiJson)
-	} else {
-		return "", fmt.Errorf("%w: unknown type, vmi %s", err, vmi.ObjectMeta.Name)
-	}
+	return ""
 }
 
 func prepareVmiConsole(vmi v12.VirtualMachineInstance, vmiType string) error {
