@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  *
- * Copyright 2022 Red Hat, Inc.
+ * Copyright The KubeVirt Authors.
  *
  */
 
@@ -67,7 +67,7 @@ const (
 type memoryDumpFunction func(name, namespace, claimNames string)
 type removeMemoryDumpFunction func(name, namespace string)
 
-var _ = SIGDescribe("Memory dump", func() {
+var _ = Describe(SIG("Memory dump", func() {
 	var (
 		virtClient         kubecli.KubevirtClient
 		memoryDumpPVCName  string
@@ -449,7 +449,7 @@ var _ = SIGDescribe("Memory dump", func() {
 			}
 		})
 	})
-})
+}))
 
 // createExecutorPodWithPVC creates a Pod with the passed in PVC mounted under /pvc. You can then use the executor utilities to
 // run commands against the PVC through this Pod.
