@@ -242,7 +242,7 @@ var _ = Describe(SIG("Storage", func() {
 			}
 
 			Context("should be successfully", func() {
-				DescribeTable("started", decorators.Conformance, func(newVMI VMICreationFunc, imageOwnedByQEMU bool) {
+				DescribeTable("started", func(newVMI VMICreationFunc, imageOwnedByQEMU bool) {
 					pvcName := diskAlpineHostPath
 					if !imageOwnedByQEMU {
 						// Setup hostpath PV that points at non-root owned image with chmod 640
@@ -253,14 +253,25 @@ var _ = Describe(SIG("Storage", func() {
 					// Start the VirtualMachineInstance with the PVC attached
 					vmi = newVMI(pvcName)
 
-					vmi = libvmops.RunVMIAndExpectLaunch(vmi, 180)
+					if imageOwnedByQEMU {
+						vmi = libvmops.RunVMIAndExpectLaunch(vmi, 180)
 
-					By(checkingVMInstanceConsoleOut)
-					Expect(console.LoginToAlpine(vmi)).To(Succeed())
+						By(checkingVMInstanceConsoleOut)
+						Expect(console.LoginToAlpine(vmi)).To(Succeed())
+					} else {
+						By("Starting a VirtualMachineInstance")
+						createdVMI := libvmops.RunVMIAndExpectScheduling(vmi, 60)
+
+						By(fmt.Sprintf("Checking that VirtualMachineInstance start failed: starting at %v", time.Now()))
+						ctx, cancel := context.WithCancel(context.Background())
+						defer cancel()
+						event := watcher.New(createdVMI).Timeout(60*time.Second).SinceWatchedObjectResourceVersion().WaitFor(ctx, watcher.WarningEvent, "SyncFailed")
+						Expect(event.Message).To(ContainSubstring("Could not open '/var/run/kubevirt-private/vmi-disks/disk0/disk.img': Permission denied"), "VMI should not be started")
+					}
 				},
 					Entry("[test_id:3130]with Disk PVC", newRandomVMIWithPVC, true),
 					Entry("[test_id:3131]with CDRom PVC", newRandomVMIWithCDRom, true),
-					Entry("hostpath disk image file not owned by qemu", newRandomVMIWithPVC, false),
+					Entry("unless hostpath disk image file not owned by qemu", newRandomVMIWithPVC, false),
 				)
 			})
 
@@ -394,7 +405,7 @@ var _ = Describe(SIG("Storage", func() {
 				})
 
 				// The following case is mostly similar to the alpine PVC test above, except using different VirtualMachineInstance.
-				It("[test_id:3136]started with Ephemeral PVC", decorators.Conformance, func() {
+				It("[test_id:3136]started with Ephemeral PVC", func() {
 					pvName = diskAlpineHostPath
 
 					vmi = libvmi.New(
