@@ -46,49 +46,51 @@ const (
 )
 
 type templateData struct {
-	Namespace              string
-	CDINamespace           string
-	CSVNamespace           string
-	DockerTag              string
-	DockerPrefix           string
-	ImagePrefix            string
-	ImagePullPolicy        string
-	Verbosity              string
-	CsvVersion             string
-	QuayRepository         string
-	ReplacesCsvVersion     string
-	OperatorDeploymentSpec string
-	OperatorCsv            string
-	OperatorRules          string
-	KubeVirtLogo           string
-	PackageName            string
-	CreatedAt              string
-	VirtOperatorSha        string
-	VirtApiSha             string
-	VirtControllerSha      string
-	VirtHandlerSha         string
-	VirtLauncherSha        string
-	VirtExportProxySha     string
-	VirtExportServerSha    string
-	GsSha                  string
-	PrHelperSha            string
-	SidecarShimSha         string
-	RunbookURLTemplate     string
-	PriorityClassSpec      string
-	FeatureGates           []string
-	InfraReplicas          uint8
-	TestImageReplicas      string
-	GeneratedManifests     map[string]string
-	VirtOperatorImage      string
-	VirtApiImage           string
-	VirtControllerImage    string
-	VirtHandlerImage       string
-	VirtLauncherImage      string
-	VirtExportProxyImage   string
-	VirtExportServerImage  string
-	GsImage                string
-	PrHelperImage          string
-	SidecarShimImage       string
+	Namespace                          string
+	CDINamespace                       string
+	CSVNamespace                       string
+	DockerTag                          string
+	DockerPrefix                       string
+	ImagePrefix                        string
+	ImagePullPolicy                    string
+	Verbosity                          string
+	CsvVersion                         string
+	QuayRepository                     string
+	ReplacesCsvVersion                 string
+	OperatorDeploymentSpec             string
+	OperatorCsv                        string
+	OperatorRules                      string
+	KubeVirtLogo                       string
+	PackageName                        string
+	CreatedAt                          string
+	VirtOperatorSha                    string
+	VirtApiSha                         string
+	VirtControllerSha                  string
+	VirtHandlerSha                     string
+	VirtLauncherSha                    string
+	VirtExportProxySha                 string
+	VirtExportServerSha                string
+	VirtSynchronizationControllerSha   string
+	GsSha                              string
+	PrHelperSha                        string
+	SidecarShimSha                     string
+	RunbookURLTemplate                 string
+	PriorityClassSpec                  string
+	FeatureGates                       []string
+	InfraReplicas                      uint8
+	TestImageReplicas                  string
+	GeneratedManifests                 map[string]string
+	VirtOperatorImage                  string
+	VirtApiImage                       string
+	VirtControllerImage                string
+	VirtHandlerImage                   string
+	VirtLauncherImage                  string
+	VirtExportProxyImage               string
+	VirtExportServerImage              string
+	VirtSynchronizationControllerImage string
+	GsImage                            string
+	PrHelperImage                      string
+	SidecarShimImage                   string
 }
 
 func main() {
@@ -115,6 +117,7 @@ func main() {
 	virtLauncherSha := flag.String("virt-launcher-sha", "", shaEnvDeprecationMsg)
 	virtExportProxySha := flag.String("virt-exportproxy-sha", "", shaEnvDeprecationMsg)
 	virtExportServerSha := flag.String("virt-exportserver-sha", "", shaEnvDeprecationMsg)
+	virtSynchronizationControllerSha := flag.String("virt-synchronization-controller-sha", "", shaEnvDeprecationMsg)
 	gsSha := flag.String("gs-sha", "", "")
 	prHelperSha := flag.String("pr-helper-sha", "", "")
 	sidecarShimSha := flag.String("sidecar-shim-sha", "", "")
@@ -129,6 +132,7 @@ func main() {
 	virtLauncherImage := flag.String("virt-launcher-image", "", "custom image for virt-launcher. "+customImageExample)
 	virtExportProxyImage := flag.String("virt-export-proxy-image", "", "custom image for virt-export-proxy. "+customImageExample)
 	virtExportServerImage := flag.String("virt-export-server-image", "", "custom image for virt-export-server. "+customImageExample)
+	virtSynchronizationControllerImage := flag.String("virt-synchronization-controller-image", "", "custom image for virt-synchronization-controller. "+customImageExample)
 	gsImage := flag.String("gs-image", "", "custom image for gs. "+customImageExample)
 	prHelperImage := flag.String("pr-helper-image", "", "custom image for pr-helper. "+customImageExample)
 	sidecarShimImage := flag.String("sidecar-shim-image", "", "custom image for sidecar-shim. "+customImageExample)
@@ -170,6 +174,7 @@ func main() {
 		data.VirtLauncherSha = *virtLauncherSha
 		data.VirtExportProxySha = *virtExportProxySha
 		data.VirtExportServerSha = *virtExportServerSha
+		data.VirtSynchronizationControllerSha = *virtSynchronizationControllerSha
 		data.GsSha = *gsSha
 		data.PrHelperSha = *prHelperSha
 		data.SidecarShimSha = *sidecarShimSha
@@ -188,6 +193,7 @@ func main() {
 		data.VirtLauncherImage = *virtLauncherImage
 		data.VirtExportProxyImage = *virtExportProxyImage
 		data.VirtExportServerImage = *virtExportServerImage
+		data.VirtSynchronizationControllerImage = *virtSynchronizationControllerImage
 		data.GsImage = *gsImage
 		data.PrHelperImage = *prHelperImage
 		data.SidecarShimImage = *sidecarShimImage
@@ -217,6 +223,7 @@ func main() {
 		data.VirtLauncherSha = "{{.VirtLauncherSha}}"
 		data.VirtExportProxySha = "{{.VirtExportProxySha}}"
 		data.VirtExportServerSha = "{{.VirtExportServerSha}}"
+		data.VirtSynchronizationControllerSha = "{{.VirtSynchronizationControllerSha}}"
 		data.ReplacesCsvVersion = "{{.ReplacesCsvVersion}}"
 		data.OperatorDeploymentSpec = "{{.OperatorDeploymentSpec}}"
 		data.OperatorCsv = "{{.OperatorCsv}}"
@@ -230,6 +237,7 @@ func main() {
 		data.VirtLauncherImage = "{{.VirtLauncherImage}}"
 		data.VirtExportProxyImage = "{{.VirtExportProxyImage}}"
 		data.VirtExportServerImage = "{{.VirtExportServerImage}}"
+		data.VirtSynchronizationControllerImage = "{{.VirtSynchronizationControllerImage}}"
 		data.GsImage = "{{.GsImage}}"
 		data.PrHelperImage = "{{.PrHelperImage}}"
 		data.SidecarShimImage = "{{.SidecarShimImage}}"
@@ -301,6 +309,7 @@ func getOperatorDeploymentSpec(data templateData, indentation int) string {
 		data.VirtLauncherSha,
 		data.VirtExportProxySha,
 		data.VirtExportServerSha,
+		data.VirtSynchronizationControllerSha,
 		data.GsSha,
 		data.PrHelperSha,
 		data.SidecarShimSha,
@@ -311,6 +320,7 @@ func getOperatorDeploymentSpec(data templateData, indentation int) string {
 		data.VirtLauncherImage,
 		data.VirtExportProxyImage,
 		data.VirtExportServerImage,
+		data.VirtSynchronizationControllerImage,
 		data.GsImage,
 		data.PrHelperImage,
 		data.SidecarShimImage,
